function TS = DRVTS1(t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka)
%==========================================================================
% DRVTS1 - funkcia vytvoren pre systm dvojkapacitn sprudov rrkov 
% vmennk tepla. Funkcia na zklade zadanch vstupnch parametrov vypota 
% teploty mdia vo vntornej rrke a vonkajej rrke pozdl vmennika tepla
% v sekoch urench pre diskretizciou. Tieto premenn s vloen do
% vektora TS. Funkcia je vyuvan v s-funkcii DRVTSS.
% vstupn parametre:
%       t1 - teplota mdia na vstupe do vntornej rrky vmennka tepla,
%            t.j. theta1(0). Rozmer (1 x 1) 
%       t3 - teplota mdia na vstupe do vonkajej rrky vmennka tepla,
%            t.j. theta3(0). Rozmer (1 x 1)
%       l  - dlka vmennka tepla. Rozmer (1 x 1)
%       n  - poet sekov pri diskretizcii. Rozmer (1 x 1)
%       d1 - priemer vntornej rrky. Rozmer (1 x 1)
%       d3 - priemer vonkajej rrky. Rozmer (1 x 1)
%       h  - hrbka steny rrky. Rozmer (1 x 1)
%       m1 - hmotnostn tok mdia vo vntornej rrke. Rozmer (1 x 1)
%       m3 - hmotnostn tok mdia vo vonkajej rrke. Rozmer (1 x 1)
%       ro - vektor hustt. Rozmer (1 x 2), priom jednotliv prvky
%            zodpovedaj:   - ro(1) - hustota mdia vo vntornej rrke
%                           - ro(2) - hustota mdia vo vonkajej rrke     
%       cp - vektor pecifickch tepelnch kapact. Rozmer (1 x 2), priom
%            jednotliv prvky vektora zodpovedaj:
%              cp(1) - pecifick tepeln kapacita mdia vo vntornej rrke
%              cp(2) - pecifick tepeln kapacita mdia vo vonkajej rrke
%       ka - vektor koeficientov prestupu tepla. Rozmer (1 x 3), priom
%            jednotliv prvky vektora zodpovedaj:
%               ka(1) - koeficient prestupu tepla prdenm zo steny rrky
%                       do mdia vo vntornej rrke
%               ka(2) - tepeln vodivos steny rrky 
%               ka(3) - koeficient prestupu tepla prdenm z mdia vo
%                       vonkajej rrke do steny rrky
% vstupn parametre:
%       TS - matica teplt. Rozmer (2 x n), kde riadok zodpoved prslunej
%            teplote a stlpec prslunmu seku pri diskretizcii. Tvar
%            matice TS = [TS1; TS3], kde:
%               TS1 - vektor teplt mdia vo vntornej rrke pozdl vmennka 
%                     tepla pre jednotliv seky diskretizcie.
%               TS3 - vektor teplt mdia vo vonkajej rrke pozdl vmennka
%                     tepla pre jednotliv seky diskretizcie.
%==========================================================================

% test sprvneho zadania vstupnch parametrov
if nargin == 12
    % priradenie premennych
    ro1 = ro(1);        ro3 = ro(2);
    cp1 = cp(1);        cp3 = cp(2);
    alfa12 = ka(1);    lambda = ka(2);    alfa23 = ka(3);
    % vpoet kontnt k13, V1, V3, A12, A23, S1, S3, q1, q3, dz
    d2 = d1+2*h;        d13= (d1+d2)/2;
    q1 = m1/(ro1);      q3 = m3/(ro3);
    k13= 1/(1/alfa12 + 1/alfa23 + h/lambda);
    S1 = (pi*(d1^2))/4;
    S3 = (pi*(d3^2-d2^2))/4;
    V1 = S1;           V3 = S3;
    A13 = pi*d13;      dz = l/n;
    
    % vpoet kontnt T1, w1;
    T1 = (ro1*cp1*V1)/(k13*A13);
    w1 = q1/S1;
    % vpoet kontnt T1, w1;
    T3 = (ro3*cp3*V3)/(k13*A13); 
    w3 = q3/S3;
    
    % vpoet kontnt a1, b1
    a1 = (T1*w1)/dz;
    b1 = ((T1*w1)/dz +1);
    % vpoet kontnt a3, b3
    a3 = (T3*w3)/dz;
    b3 = ((T3*w3)/dz +1);

    ts1=zeros(1,n+1);
    ts3=zeros(1,n+1);
    ts1(1) = t1;
    ts3(1) = t3;
    
    %vpoet teplot theta1 pozdl vmennka tepla v RS
    for(i=1:1:n)
        A = [ 1      (-1/b1);
             (-1/b3)     1 ];
        B = [(a1/b1*ts1(i));
             (a3/b3*ts3(i))];
        x = A\B;
        TS(1,i)=x(1);
        TS(2,i)=x(2);
        ts1(i+1)= x(1);
        ts3(i+1)= x(2);    
    end
else
    error('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
%==========================================================================
