function A = DRVTS_A(l,n,d1,d3,h,m1,m3,ro,cp,ka)
%==========================================================================
% DRVTS_A - funkcia, ktor vypota maticu A v ustlenom (rovnovnom)
% stave. Funkcia je vytvren pre maticov tvar modelu dvojkapacitnho
% sprudovho rrokovho vmennka tepla  a je pouit v m-file DRVTS_M.
% vstupn parametre:
%       l  - dlka vmennka tepla. Rozmer (1 x 1)
%       n  - poet sekov pri diskretizcii. Rozmer (1 x 1)
%       d1 - priemer vntornej rrky. Rozmer (1 x 1)
%       d3 - priemer vonkajej rrky. Rozmer (1 x 1)
%       h  - hrbka steny rrky. Rozmer (1 x 1)
%       m1 - hmotnostn tok mdia vo vntornej rrke. Rozmer (1 x 1)
%       m3 - hmotnostn tok mdia vo vonkajej rrke. Rozmer (1 x 1)
%       ro - vektor hustt. Rozmer (1 x 2), priom jednotliv prvky
%            zodpovedaj:   - ro(1) - hustota mdia vo vntornej rrke
%                           - ro(2) - hustota mdia vo vonkajej rrke     
%       cp - vektor pecifickch tepelnch kapact. Rozmer (1 x 2), priom
%            jednotliv prvky vektora zodpovedaj:
%              cp(1) - pecifick tepeln kapacita mdia vo vntornej rrke
%              cp(2) - pecifick tepeln kapacita mdia vo vonkajej rrke
%       ka - vektor koeficientov prestupu tepla. Rozmer (1 x 3), priom
%            jednotliv prvky vektora zodpovedaj:
%               ka(1) - koeficient prestupu tepla prdenm zo steny rrky
%                       do mdia vo vntornej rrke
%               ka(2) - tepeln vodivos steny rrky 
%               ka(3) - koeficient prestupu tepla prdenm z mdia vo
%                       vonkajej rrke do steny rrky
%vstupn parametre:
%       A - matica A - matica systmu
%==========================================================================

% test sprvneho zadania vstupnch parametrov
if nargin == 10
    % priradenie premennych
    ro1 = ro(1);        ro3 = ro(2);
    cp1 = cp(1);        cp3 = cp(2);
    alfa12 = ka(1);    lambda = ka(2);    alfa23 = ka(3);
    % vpoet kontnt k13, V1, V3, A12, A23, S1, S3, q1, q3, dz
    d2 = d1+2*h;        d13= (d1+d2)/2;
    q1 = m1/(ro1);      q3 = m3/(ro3);
    k13= 1/(1/alfa12 + 1/alfa23 + h/lambda);
    S1 = (pi*(d1^2))/4;
    S3 = (pi*(d3^2-d2^2))/4;
    V1 = S1;            V3 = S3;
    A13 = pi*d13;       dz = l/n;
    
    % vpoet kontnt T1, w1;
    T1 = (ro1*cp1*V1)/(k13*A13);
    w1 = q1/S1;
    % vpoet kontnt T1, w1;
    T3 = (ro3*cp3*V3)/(k13*A13); 
    w3 = q3/S3;
    
    % vpoet kontnt a1, b1
    a1 = (T1*w1)/dz;
    b1 = ((T1*w1)/dz +1);
    % vpoet kontnt a3, b3
    a3 = (T3*w3)/dz;
    b3 = ((T3*w3)/dz +1);
    
    % matica A
    % prv 3 riadky
    for(i=1:1:2)
        for(j=1:1:2*n)
            if i==1
                if(j==i | j==i+1)
                    if j==i
                        A(i,j)=(-b1/T1);
                    else
                        A(i,j)=(1/T1);
                    end
                else
                    A(i,j)=0;
                end
            end
            if i==2
                if(j==i | j==i-1)
                    if j==i-1      
                        A(i,j)=(1/T3);
                    else
                        A(i,j)=(-b3/T3);
                    end
                else
                    A(i,j)=0;
                end
            end
        end
    end      
    % ostatne riadky pre T(1,i)
    for(i=3:2:2*n)    
        for(j=1:1:2*n)
            if(i==j | j==i-2 | j==i+1)
                if(i==j)
                    A(i,j)=(-b1/T1);
                end
                if(j==i-2)
                    A(i,j)=(a1/T1);
                end
                if(j==i+1)
                    A(i,j)=(1/T1);
                end
            else
                A(i,j)=0;
            end
        end
    end
    for(i=4:2:2*n)         
        for(j=1:1:2*n)
            if(i==j | j==i-2 | j==i-1)
                if(i==j)
                    A(i,j)=(-b3/T3);
                end
                if(j==i-2)
                    A(i,j)=(a3/T3);
                end
                if(j==i-1)
                    A(i,j)=(1/T3);
                end
            else
                A(i,j)=0;
            end
        end
    end
else
    error('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
%==========================================================================
                
                
                
    
