function B = DRVTS_B(l,n,d1,d3,h,m1,m3,ro,cp,ka,vst)
%==========================================================================
% DRVTS_B - funkcia, ktor vypota maticu B v ustlenom (rovnovnom)
% stave. Funkcia je vytvren pre maticov tvar modelu dvojkapacitnho
% sprudovho rrkovho vmennka tepla a je pouit v m-file DRVTS_M.
% vstupn parametre:
%       l  - dlka vmennka tepla. Rozmer (1 x 1)
%       n  - poet sekov pri diskretizcii. Rozmer (1 x 1)
%       d1 - priemer vntornej rrky. Rozmer (1 x 1)
%       d3 - priemer vonkajej rrky. Rozmer (1 x 1)
%       h  - hrbka steny rrky. Rozmer (1 x 1)
%       m1 - hmotnostn tok mdia vo vntornej rrke. Rozmer (1 x 1)
%       m3 - hmotnostn tok mdia vo vonkajej rrke. Rozmer (1 x 1)
%       ro - vektor hustt. Rozmer (1 x 2), priom jednotliv prvky
%            zodpovedaj:   - ro(1) - hustota mdia vo vntornej rrke
%                           - ro(2) - hustota mdia vo vonkajej rrke     
%       cp - vektor pecifickch tepelnch kapact. Rozmer (1 x 2), priom
%            jednotliv prvky vektora zodpovedaj:
%              cp(1) - pecifick tepeln kapacita mdia vo vntornej rrke
%              cp(2) - pecifick tepeln kapacita mdia vo vonkajej rrke
%       ka - vektor koeficientov prestupu tepla. Rozmer (1 x 3), priom
%            jednotliv prvky vektora zodpovedaj:
%               ka(1) - koeficient prestupu tepla prdenm zo steny rrky
%                       do mdia vo vntornej rrke
%               ka(2) - tepeln vodivos steny rrky 
%               ka(3) - koeficient prestupu tepla prdenm z mdia vo
%                       vonkajej rrke do steny rrky
%       vst -  vektor aknch velin, ktor nadobda hodnoty 0 - 1 a jeho
%              rozmer je (1 x 2) t.j. [t1 t3]
%                   0 = ak nie je dan veliina akn - riadiaca
%                   1 = ak je dan veliina akn - riadiaca
% vstupn parametre:
%       B - matica B - matica riadenia
%==========================================================================

% test sprvneho potu vstupnch parametrov
if nargin == 11
    if length(vst)==2
        % priradenie premennych
        ro1 = ro(1);        ro3 = ro(2);
        cp1 = cp(1);        cp3 = cp(2);
        alfa12 = ka(1);     lambda = ka(2);     alfa23 = ka(3);
        % vpoet kontnt k13, V1, V3, A12, A23, S1, S3, q1, q3, dz
        d2 = d1+2*h;        d13= (d1+d2)/2;
        q1 = m1/(ro1);      q3 = m3/(ro3);
        k13= 1/(1/alfa12 + 1/alfa23 + h/lambda);
        S1 = (pi*(d1^2))/4;
        S3 = (pi*(d3^2-d2^2))/4;
        V1 = S1;            V3 = S3;
        A13 = pi*d13;       dz = l/n;
    
        % vpoet kontnt T1, w1;
        T1 = (ro1*cp1*V1)/(k13*A13);
        w1 = q1/S1;
        % vpoet kontnt T1, w1;
        T3 = (ro3*cp3*V3)/(k13*A13); 
        w3 = q3/S3;
        
        % vpoet kontnt a1, b1
        a1 = (T1*w1)/dz;
        b1 = ((T1*w1)/dz +1);
        % vpoet kontnt a3, b3
        a3 = (T3*w3)/dz;
        b3 = ((T3*w3)/dz +1);
    
        %urenie potu aknch velin a priradenie k vstupnm prietokom
        cc=find(vst);
        % vpoet jednotlivch prvkov matice B
        for (i=1:1:2*n)
            for(j=1:1:length(cc))
                if(cc(j)==1)
                    if(i==1)
                        B(i,j)=(a1/T1);
                    else
                        B(i,j)=0;                
                    end
                end
                if(cc(j)==2)
                    if(i==2)
                        B(i,j)=(a3/T3);
                    else
                        B(i,j)=0;                
                    end
                end
            end
        end
    else          
        error ('NESPRAVNE ZADANY VEKTOR RIADIACICH - AKCNYCH VELICIN')
    end
else
    error ('NESPRAVNE ZADANY VSTUPNY POCET  PARAMETROV')
end
%==========================================================================
