%==========================================================================
% JRVTSS - S-Function, pouvan v simulinkovom bloku JEDNOKAPACITNY RURKOVY
% VYMENNIK TEPLA - SUPRUDOVY, ktor pota teploty vntorneho, vonkajieho
% mdia pre jednotliv asti vmennka uren diskretizciou v neustlenom
% t.j. dynamickom stave.
% Pouva funkcie: - JRVTS1.m 
%                  - JRVTS2.m 
%                  - JRVTS4.m 
%                  - JRVTS5.m 
% vstupn parametre:
%       t1 - teplota mdia na vstupe do vntornej rrky vmennka tepla,
%            t.j. theta1(0). Rozmer (1 x 1) 
%       t3 - teplota mdia na vstupe do vonkajej rrky vmennka tepla,
%            t.j. theta3(0). Rozmer (1 x 1)
%       l  - dlka vmennka tepla. Rozmer (1 x 1)
%       n  - poet sekov pri diskretizcii. Rozmer (1 x 1)
%       d12 - priemer vntornej rrky. Rozmer (1 x 1)
%       d23 - priemer vonkajej rrky. Rozmer (1 x 1)
%       m1  - hmotnostn tok mdia vo vntornej rrke. Rozmer (1 x 1)
%       ro1 - hustota mdia vo vntornej rrke. Rozmer (1 x 1)
%       cp1 - pecifick tepeln kapacita mdia vo vntornej rrke
%       alfa13 - koeficient prestupu tepla prdenm z vntornho mdia do
%                 vonkajieho mdia
%       vst -  vektor aknch velin, ktor nadobda hodnoty 0 - 1 a jeho
%              rozmer je (1 x 3) t.j. [m1 t1 t3]
%                   0 = ak nie je dan veliina akn - riadiaca
%                   1 = ak je dan veliina akn - riadiaca
%       por -  vektor poruchovch velin, ktor nadobda hodnoty 0 - 1 a
%              jeho rozmer je (1 x 3) t.j. [m1 t1 t3]
%                   0 = ak nie je dan veliina poruchov
%                   1 = ak je dan veliina akn - poruchov
%       C - matica C - matica vstupu - vytvoren pomocou funkcie JRVTS4
% vstupn parametre - as mdlOutputs 
%       sys = vystup - teploty prisluchajce jednotlivm astiam a mdiam
%=========================================================================


function [sys,x0,str,ts] = JRVTSS(t,x,u,flag,vst,por,t1,t3,l,n,d1,d3,m1,ro1,cp1,ka,C)
switch flag,
  % Initialization %
    case 0,
    [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,vst,por,t1,t3,l,n,d1,d3,m1,ro1,cp1,ka,C);
  % Derivatives %
    case 1,
    sys=mdlDerivatives(t,x,u,vst,por,t1,t3,l,n,d1,d3,m1,ro1,cp1,ka,C);
  % Update %
    case 2,
    sys=mdlUpdate(t,x,u);
  % Outputs %
    case 3,
    sys=mdlOutputs(t,x,u,C);
  % GetTimeOfNextVarHit %
    case 4,
    sys=mdlGetTimeOfNextVarHit(t,x,u);
  % Terminate %
    case 9,
    sys=mdlTerminate(t,x,u);
  % Unexpected flags %
    otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

%=============================================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the S-function.
%=============================================================================

function [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,vst,por,t1,t3,l,n,d1,d3,m1,ro1,cp1,ka,C)

% urenie potu vstupov
[r,p]=size(C);

% urenie potu vstupov
in=cat(2,vst,por);
input=length(find(in));

sizes = simsizes;

sizes.NumContStates  = n;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = r;
sizes.NumInputs      = input;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
% vpoet vektora teplt mdia vo vntornej rrke pozdl vmennka tepla pre seky
% uren diskretizciou v ustlenom - rovnovnom stave
x0= JRVTS1(t1,t3,l,n,d1,d3,m1,ro1,cp1,ka);
str = [];
ts  = [0 0];

%=============================================================================
% mdlDerivatives
% Return the derivatives for the continuous states.
%=============================================================================

function sys=mdlDerivatives(t,x,u,vst,por,t1,t3,l,n,d1,d3,m1,ro1,cp1,ka,C)

% priradenie aknch a poruchovch velin jednotlivm premennm
    [m11,t11,t31]=JRVTS5(vst,por,u,m1,t1,t3);
% vpoet derivcii teplt pre mdium vo vntornej rrke pozdl vmennka tepla
% pre seky uren diskretizciou v dynamickom stave
    T = JRVTS2(x,t11,t31,l,n,d1,d3,m11,ro1,cp1,ka);
    sys = T';

    
%=============================================================================
% mdlUpdate
% Handle discrete state updates, sample time hits, and major time step
% requirements.
%=============================================================================

function sys=mdlUpdate(t,x,u)
	sys = [];

%=============================================================================
% mdlOutputs
% Return the block outputs.
%=============================================================================
    
function sys=mdlOutputs(t,x,u,C)
% urenie vstupnch velin - ktor sa bud sledova
[rr,cc]=size(C);
    for(i=1:1:rr)
        for(j=1:1:cc)
            if(C(i,j)~=0)
                vystup(i)=x(j);
            end
        end
    end
 % vstupn veliiny
    sys=vystup';

%=============================================================================
% mdlTerminate
% Perform any end of simulation tasks.
%=============================================================================

function sys=mdlTerminate(t,x,u)
	sys = [];

%=============================================================================
