function G = kolona1(x,N,F,axb,nii,nF,xF,nL,nD,nV,nW,Hi)
%==========================================================================
% KOLONA1.M - funkcia vytvoren pre systm etov rektifikan kolona.
% Funkcia generuje na zklade zadanch vstupnch parametrov vektor
% zvislost zmien zloenia kvapalnej fzy na jednotlivch etach od asu
% a transponuje vektor do vstupnej premennej G. Premenn G je nasledovne
% vyuvan vo funkcii KOLONA2 a v s-funkciach KOLONA_X a KOLONA_Y.
% vstupn parametre: 
%       x - vektor zloenia kvapalnej fzy na jednotlivch etach, ktor
%           je generovan potaom, rozmer (1 x n+2).
%       N - poet eti kolony - nie je zapotan vark a kondenztor
%       F - nstrekov et
%       axb - koeficienty rovnovnej krivky
%           - krivka m tvar
%                                ax^2 + bx + c
%                           y = ---------------
%                                dx^2 + ex + c           
%       nii - innos varka a jednotlivch eti.  Hodnoty treba zadva
%             v percentch. Rozmer vektora me by 1x2 alebo 1x(n+2).
%               1x2 - ak je innos eti rovnak, potom tvar vektora je
%                     [innos eti, innos varka]
%               1x(n+2) - ak s innosti eti rzne, potom tvar vektoraje
%                         [.. innos i-tej ete .. innos varka] 
%       nF - tok ltkovho mnostva privdzanho nstreku
%       xF - molov zlomok (zloenie) privdzanho nstreku
%       nD - prietok ltkovho mnostva destiltu
%       nL - tok ltkovho mnostva sptnho toku
%       nV - tok ltkovho mnostva pr odchdzajcich z hlavy kolony
%       nW - tok ltkovho mnostva destilnho zvyku
%       Hi - zdre kvapaliny na jednotlivch etach a vo varku. Rozmer
%            vektora me by 1x2 alebo 1x(n+2).
%               1x2 - ak s zdre kvapaliny na jednotlivch etach rovnak
%               1x(n+2) - ak s zdre kvapaliny na jednotlivch etach a
%                         vo varku rzne.
% vstupn parametre
%       G - transponovan vektor ktor obsahuje zvislosti zmien zloenia
%           kvapalnej fzy na jednotlivch etach od asu. 
%           Rozmer (1 x n+2)
%==========================================================================

%test sprvneho zadania potu vstupnch parametrov
if nargin == 12 

% priradenie premennch
n=N;
k=F;

% priradenie premenej nii a urenie jednotlivch premennych ni(i)
if(length(nii) == 2)
    nii=nii/100;
    for(i=1:1:n+1)
        ni(i)=nii(1);
    end
    niv=nii(2);
else
    nii=nii/100;
    if length(nii) == (n+2)
        for(i=1:1:n+1)
            ni(i)=nii(i);
        end
        niv=nii(n+2);
    else
        error('ZLE ZADANY VEKTOR UCINNOSTI JEDNOTLIVYCH ETAZI A VARAKA')
    end
end

% priradenie premenej Hi a urenie jednotlivch premennych H(i)
if(length(Hi) == 2)
    for(i=1:1:n+1)
        H(i)=Hi(1);
    end
    H(n+2)=Hi(2);
else
    if length(Hi) == (n+2)
        for(i=1:1:n+1)
            H(i)=Hi(i);
        end
        H(n+2)=Hi(n+2);
    else
        error('ZLE ZADANY VEKTOR ZADRZI KVAPALINY NA JEDNOTLIVYCH ETAZACH')
    end
end
% parametre rovnovnej krivky
a=axb(1);
b=axb(2);
c=axb(3);
d=axb(4);
e=axb(5);
% dopotanie premennch     nF - zadan vdy
% vpoty neznmych

% zadane nf,nw    nv alebo nl
if nF~=-1 & nW~=-1
    nD = nF - nW;
    if nV~=-1 & nL==-1
        nL = nV - nD;
    end
    if nV==-1 & nL~=-1
        nV = nL + nD;
    end
end

% zadane nf      nv,nl,nd 
if nF~=-1 & nW==-1
   if nV~=-1 & nL~=-1
        nD = nV - nL;
        nW = nF - nD;
    end
    if nD~=-1 & nL~=-1
        nV = nL + nD;
        nW = nF - nD;      
    end
    if nD~=-1 & nV~=-1
        nL = nV - nD;
        nW = nF - nD;      
    end
end

% vpoet derivcie zloenia  kvapalnej fzy
% vark n+1 et
yr(n+2) = (a*(x(n+2)^2)+b*x(n+2)+c)/(d*(x(n+2)^2)+e*x(n+2)+1);
y(n+2) = niv*yr(n+2);
f(n+2) = ((nF+nL)*x(n+1) - nV*y(n+2) - nW*x(n+2))/H(n+2);
% ete n-(k+1) - ochudobovacia as
for (i=n+1:(-1):k+2)
    yr(i) = (a*(x(i)^2)+b*x(i)+c)/(d*(x(i)^2)+e*x(i)+1);
    y(i) = ni(i)*yr(i)+(1-ni(i))*y(i+1);
    f(i) = ((nF+nL)*x(i-1) + nV*y(i+1) - nV*y(i) - (nF+nL)*x(i))/H(i);
end
% nstrekov et k    
i=k+1;
    yr(i) = (a*(x(i)^2)+b*x(i)+c)/(d*(x(i)^2)+e*x(i)+1);
    y(i) = ni(i)*yr(i)+(1-ni(i))*y(i+1);
    f(i) = (nF*xF + nL*x(i-1) + nV*y(i+1) - nV*y(i) - (nF+nL)*x(i))/H(i);
% ete (k-1)-1 obohacovacia as
for (i=k:(-1):2)
    yr(i) = (a*(x(i)^2)+b*x(i)+c)/(d*(x(i)^2)+e*x(i)+1);
    y(i) = ni(i)*yr(i)+(1-ni(i))*y(i+1);
    f(i) = (nL*x(i-1) + nV*y(i+1) - nV*y(i) - nL*x(i))/H(i);
end
% nult et x0
i=1;    
    f(i)=(nV*y(i+1)-nL*x(i)-nD*x(i))/H(i);

% vstupn premenn G - derivcia zloenia kvapalnej fzy    
G = f';

else 
  error('NESPRAVNE ZADANIE PARAMETROV')
end

%==========================================================================

