function K = kolona2(N,F,axb,nii,nF,xF,nL,nD,nV,nW,Hi)
%==========================================================================
% KOLONA2.M - funkcia vytvoren pre systm etov rektifikan kolona. Na
% zklade zadanch vstupnch parametrov s pomocou funkcie fsolve
% vypotan hodnoty zloenia kvapalnej fzy na jednotlivch etach v
% ustlenom - rovnovnom stave t.j. vektor - [x0 x1 ... xn x(n+1)].
%       N - poet eti kolony - nie je zapotan vark a kondenztor
%       F - nstrekov et
%       axb - koeficienty rovnovnej krivky
%           - krivka m tvar
%                                ax^2 + bx + c
%                           y = ---------------
%                                dx^2 + ex + c           
%       nii - innos varka a jednotlivch eti.  Hodnoty treba zadva
%             v percentch. Rozmer vektora me by 1x2 alebo 1x(n+2).
%               1x2 - ak je innos eti rovnak, potom tvar vektora je
%                     [innos eti, innos varka]
%               1x(n+2) - ak s innosti eti rzne, potom tvar vektoraje
%                         [.. innos i-tej ete .. innos varka] 
%       nF - tok ltkovho mnostva privdzanho nstreku
%       xF - molov zlomok (zloenie) privdzanho nstreku
%       nD - tok ltkovho mnostva destiltu
%       nL - tok ltkovho mnostva sptnho toku
%       nV - tok ltkovho mnostva pr odchdzajcich z hlavy kolony
%       nW - tok ltkovho mnostva destilnho zvyku
%       Hi - zdre kvapaliny na jednotlivch etach a vo varku. Rozmer
%            vektora me by 1x2 alebo 1x(n+2).
%               1x2 - ak s zdre kvapaliny na jednotlivch etach rovnak
%               1x(n+2) - ak s zdre kvapaliny na jednotlivch etach 
%                         rzne.
% vstupn parametre:
%       K - vektor zloenia kvapalnej fzy na jednotlivch etach v
%           rovnovnom stave - vektor - [x0 x1 ... xn x(n+1)].
%==========================================================================

x0=zeros(1,N+2);
x0(1)=0.9;
for(i=N+1:-1:2)
    x0(i)=x0(i-1)-0.02;
end
[x]=fsolve('kolona1',x0,optimset('fsolve'),N,F,axb,nii,nF,xF,nL,nD,nV,nW,Hi);

% zloenie kvapalnej fzy na jednotlivch etach v rovnovnom stave
K=x(1:end);
