%==========================================================================
% MATICA - m-file vytvoren pre linearizovan matematick model zsobnkov
% kvapaliny. Na zklade zadanch vstupnch parametrov pre jednotliv
% funkcie s vypotan zodpovedajce hodnoty.
% pouit funkcie:
%   h = zasobniky2(q,a,d,e,f)   - rieenie vok hladn v ustlenom stave
%                                 v jednotlivch zsobnkoch kvapaliny
%   A = matica_A(h,a,d,e,f)     - generovanie matice A - matice systmu
%   B = matica_B(a,c,d,f)       - generovanie matice B - matice riadenia
%   C = matica_C(a,g)           - generovanie matice C - matice vstupu
%   D = matica_D(a,B,C)         - generovanie matice D 
%   hs=zasobniky3(h,C)          - vytvorenie vektora sledovanch vok
%                                 hladn v jednotlivch zsobnkov kvapaliny
% vstupn parametre:
%       a - poet zsobnkov 
%       c -  vektor aknch velin, ktor nadobda hodnoty 0 - 1 a jeho
%            rozmer je (1 x n) t.j. [qv1 qv2 .. qvn]
%                   0 = ak nie je dan veliina akn - riadiaca
%                   1 = ak je dan veliina akn - riadiaca
%       d - vektor interakci 
%               d(i) = 1 - ak je interakcia medzi i-tym a (i+1) zsobnkom
%                          kvapaliny
%               d(i) = 0 - ak nie je interakcia medzi i-tym a (i+1)
%                          zsobnkom kvapaliny
%               rozmer (1 x n).
%       e - vektor kontnt (charakteristk) ventilov [k11,k22,...,kn] pre
%           jednotliv zsobnky kvapaliny, rozmer (1 x n).
%       f - plochy prierezov zsobnkov kvapaliny [F1,F2,...,Fn],
%           rozmer (1 x n).
%       q - vektor vstupnch prietokov kvapaliny do jednotlivch zsobnkov
%           rozmer (1 x n).
% vstupn parametre:
%       h - vektor vok hladn v ustlenom stave v jednotlivch
%           zsobnkoch kvapaliny
%       A - matica systmu 
%       B - matica riadenia
%       C - matica vstupu
%       D - matica 
%       hs - vektor sledovanch vok hladn v jednotlivch zsobnkoch
%           kvapaliny [hs1,hs2,...,hsn].
%       x0 - transponovan vektor vektora hs
%==========================================================================

cc = find(c);
for (i=1:1:length(cc))
    if(i==cc(i))
        qq(i)=q(i);
    end
end

% generovanie jednotlivch parametrov pre linearizovan matematick model
h = zasobniky2(q,a,d,e,f);
A = matica_A(h,a,d,e,f);
B = matica_B(a,c,d,f);
C = matica_C(a,g);
D = matica_D(a,B,C);
hs=zasobniky3(h,C);
x0=hs';
%==========================================================================

