function TS = TRVTS1(t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka)
%==========================================================================
% TRVTS1 - funkcia vytvoren pre systm trojkapacitn sprudov rrkov 
% vmennk tepla. Funkcia na zklade zadanch vstupnch parametrov vypota 
% teploty mdia vo vntornej rrke, vonkajej rrke a teploty steny rrky
% vmennika v sekoch urench pre diskretizciou. Tieto premenn s
% vloen do vektora TS. Funkcia je vyuvan v s-funkcii TRVTSS.
% vstupn parametre:
%       t1 - teplota mdia na vstupe do vntornej rrky vmennka tepla,
%            t.j. theta1(0). Rozmer (1 x 1) 
%       t3 - teplota mdia na vstupe do vonkajej rrky vmennka tepla,
%            t.j. theta3(0). Rozmer (1 x 1)
%       l  - dlka vmennka tepla. Rozmer (1 x 1)
%       n  - poet sekov pri diskretizcii. Rozmer (1 x 1)
%       d1 - priemer vntornej rrky. Rozmer (1 x 1)
%       d3 - priemer vonkajej rrky. Rozmer (1 x 1)
%       h  - hrbka steny rrky. Rozmer (1 x 1)
%       m1 - hmotnostn tok mdia vo vntornej rrke. Rozmer (1 x 1)
%       m3 - hmotnostn tok mdia vo vonkajej rrke. Rozmer (1 x 1)
%       ro - vektor hustt. Rozmer (1 x 3), priom jednotliv prvky
%            zodpovedaj:   - ro(1) - hustota mdia vo vntornej rrke
%                           - ro(2) - hustota steny rrky
%                           - ro(3) - hustota mdia vo vonkajej rrke     
%       cp - vektor pecifickch tepelnch kapact. Rozmer (1 x 3), priom
%            jednotliv prvky vektora zodpovedaj:
%              cp(1) - pecifick tepeln kapacita mdia vo vntornej rrke
%              cp(2) - pecifick tepeln kapacita steny rrky
%              cp(3) - pecifick tepeln kapacita mdia vo vonkajej rrke
%       ka - vektor koeficientov prestupu tepla. Rozmer (1 x 2), priom
%            jednotliv prvky vektora zodpovedaj:
%               ka(1) - koeficient prestupu tepla prdenm zo steny rrky
%                       do mdia vo vntornej rrke
%               ka(2) - koeficient prestupu tepla prdenm z mdia vo
%                       vonkajej rrke do steny rrky
% vstupn parametre:
%       TS - matica teplt. Rozmer (3 x n), kde riadok zodpoved prslunej
%            teplote a stlpec prslunmu seku pri diskretizcii. Tvar
%            matice TS = [TS1; TS2; TS3], kde:
%               TS1 - vektor teplt mdia vo vntornej rrke pozdl vmennka 
%                     tepla pre jednotliv seky diskretizcie.
%               TS2 - vektor teplt steny rrky pozdl vmennka tepla pre
%                     jednotliv seky diskretizcie.
%               TS3 - vektor teplt mdia vo vonkajej rrke pozdl vmennka
%                     tepla pre jednotliv seky diskretizcie.
%==========================================================================

% test sprvneho zadania vstupnch parametrov
if nargin == 12
    % priradenie premennych
    ro1 = ro(1);    ro2 = ro(2);    ro3 = ro(3);
    cp1 = cp(1);    cp2 = cp(2);    cp3 = cp(3);    
    alfa12 = ka(1);    alfa23 = ka(2);
    % vpoet kontnt V1, V3, A12, A23, S12, S23, q1, q3, dz
    d2 = d1+2*h;        dz = l/n;
    q1 = m1/(ro1);    q3 = m3/(ro3);
    S1 = (pi*(d1^2))/4;
    S2 = (pi*(d2^2-d1^2))/4;
    S3 = (pi*(d3^2-d2^2))/4;
    V1 = S1;    V2 = S2;    V3 = S3;
    A12 = pi*d1;    A23 = pi*d2;
    
    % vpoet kontnt T1, w1;
    T1 = (ro1*cp1*V1)/(alfa12*A12);  
    w1 = q1/S1;
    % vpoet kontnt T2, Z12, Z23;
    T2 = (ro2*cp2*V2)/(alfa12*A12+alfa23*A23);
    Z12= (alfa12*A12)/(alfa12*A12+alfa23*A23);
    Z23= (alfa23*A23)/(alfa12*A12+alfa23*A23);    
    % vpoet kontnt T1, w1;
    T3 = (ro3*cp3*V3)/(alfa23*A23); 
    w3 = q3/S3;
    
    % vpoet kontnt a1, b1
    a1 = (T1*w1)/dz;
    b1 = ((T1*w1)/dz +1);
    % vpoet kontnt a3, b3
    a3 = (T3*w3)/dz;
    b3 = ((T3*w3)/dz +1);

    % vpoet teplot theta1 pozdl vmennka tepla v RS
    ts1=zeros(1,n+1);
    ts3=zeros(1,n+1);
    ts1(1) = t1;
    ts3(1) = t3;
    
    for(i=1:1:n)
        A = [(1-Z12/b1)  (-Z23/b1);
             (-Z12/b3)  (1-Z23/b3)];
        B = [(a1/b1*ts1(i));
             (a3/b3*ts3(i))];
        x = A\B;
        TS(1,i)=x(1);
        TS(3,i)=x(2);
        ts1(i+1)= x(1);
        ts3(i+1)= x(2);    
    end
    for(i=1:1:n+1)    
        ts2(i) = Z12*ts1(i)+Z23*ts3(i);
        if i>1
            TS(2,i-1) = ts2(i);
        end
    end
else
    error('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
%==========================================================================
