function F = TRVTS2(x,t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka)
%==========================================================================
% TRVTS2 - funkcia vytvoren pre systm trojkapacitn sprudov rrkov
% vmennk tepla. Funkcia generuje na zklade zadanch vstupnch parametrov 
% vektor zvislost zmien teplt mdii vo vntornej rrky, vonkajej rrky 
% a steny rrky pre jednotliv seky uren diskretizciou od asu. Tieto 
% premenn s vloen do vektora F. Premenn F je vyuvan v s-funkcii TRVTSS.
% vstupn parametre:
%       x  - vektor teplt v rovnovnom - ustlenom stave, ktor m tvar 
%               [T1(1) T2(1) T3(1)..T1(i) T2(i) T3(i)..T1(n) T2(n) T3(n)]
%            Rozmer (1 x 3n)  
%       t1 - teplota mdia na vstupe do vntornej rrky vmennka tepla,
%            t.j. theta1(0). Rozmer (1 x 1) 
%       t3 - teplota mdia na vstupe do vonkajej rrky vmennka tepla,
%            t.j. theta3(0). Rozmer (1 x 1)
%       l  - dlka vmennka tepla. Rozmer (1 x 1)
%       n  - poet sekov pri diskretizcii. Rozmer (1 x 1)
%       d1 - priemer vntornej rrky. Rozmer (1 x 1)
%       d3 - priemer vonkajej rrky. Rozmer (1 x 1)
%       h  - hrbka steny rrky. Rozmer (1 x 1)
%       m1 - hmotnostn tok mdia vo vntornej rrke. Rozmer (1 x 1)
%       m3 - hmotnostn tok mdia vo vonkajej rrke. Rozmer (1 x 1)
%       ro - vektor hustt. Rozmer (1 x 3), priom jednotliv prvky
%            zodpovedaj:   - ro(1) - hustota mdia vo vntornej rrke
%                           - ro(2) - hustota steny rrky
%                           - ro(3) - hustota mdia vo vonkajej rrke     
%       cp - vektor pecifickch tepelnch kapact. Rozmer (1 x 3), priom
%            jednotliv prvky vektora zodpovedaj:
%              cp(1) - pecifick tepeln kapacita mdia vo vntornej rrke
%              cp(2) - pecifick tepeln kapacita steny rrky
%              cp(1) - pecifick tepeln kapacita mdia vo vonkajej rrke
%       ka - vektor koeficientov prestupu tepla. Rozmer (1 x 2), priom
%            jednotliv prvky vektora zodpovedaj:
%               ka(1) - koeficient prestupu tepla prdenm zo steny rrky
%                       do mdia vo vntornej rrke
%               ka(2) - koeficient prestupu tepla prdenm z mdia vo
%                       vonkajej rrke do steny rrky
% vstupn parametre:
%       F - matica zmien teplt medi vo vntornej, vonkajej rrke a steny
%           rrky pre jednotliv seky diskretizcie od asu. Rozmer (3 x n), 
%           kde riadok zodpoved prslunej zmene teploty a stlpec 
%           prslunmu seku pri diskretizcii. Tvar F = [f1;f2;f3]
%               f1 - vektor derivcii teploty mdia vo vntornej rrke pre
%                    jednotliv seky diskretizcie poda asu.
%               f2 - vektor derivci teploty steny rrky pre jednotliv 
%                    seky diskretizcie poda asu.
%               f3 - vektor derivci teploty mdia vo vonkajej rrke pre
%                    jednotliv seky diskretizcie poda asu.
%==========================================================================

% test sprvneho zadania vstupnch parametrov
if nargin == 13
    % priradenie premennych
    ro1 = ro(1);    ro2 = ro(2);    ro3 = ro(3);
    cp1 = cp(1);    cp2 = cp(2);    cp3 = cp(3);    
    alfa12 = ka(1);    alfa23 = ka(2);
    % vpoet kontnt V1, V3, A12, A23, S12, S23, q1, q3, dz
    d2 = d1+2*h;      dz = l/n;
    q1 = m1/(ro1);    q3 = m3/(ro3);
    S1 = (pi*(d1^2))/4;
    S2 = (pi*(d2^2-d1^2))/4;
    S3 = (pi*(d3^2-d2^2))/4;
    V1 = S1;    V2 = S2;    V3 = S3;
    A12 = pi*d1;    A23 = pi*d2;

    % vpoet kontnt T1, w1;
    T1 = (ro1*cp1*V1)/(alfa12*A12);  
    w1 = q1/S1;
    % vpoet kontnt T2, Z12, Z23;
    T2 = (ro2*cp2*V2)/(alfa12*A12+alfa23*A23);
    Z12= (alfa12*A12)/(alfa12*A12+alfa23*A23);
    Z23= (alfa23*A23)/(alfa12*A12+alfa23*A23);    
    % vpoet kontnt T3, w3;
    T3 = (ro3*cp3*V3)/(alfa23*A23);  
    w3 = q3/S3;
    
    % vpoet kontnt a1, b1
    a1 = (T1*w1)/dz;
    b1 = ((T1*w1)/dz +1);
    % vpoet kontnt a3, b3
    a3 = (T3*w3)/dz;
    b3 = ((T3*w3)/dz +1);
    
    % vytvorenie vektorov vstupnch teplt potrebnch pre vpoet zmien
    % teplt pri diskretizcii
    i=1;
    for(j=1:3:3*n)
        ts(i,j)=x(j);
    end
    [e1,f1,ts1]= find(ts(1,1:end));
    i=2;
    for(j=2:3:3*n)
        ts(i,j)=x(j);
    end
    [e2,f2,ts2]= find(ts(2,1:end));
    i=3;
    for(j=3:3:3*n)
        ts(i,j)=x(j);
    end
    [e3,f3,ts3]= find(ts(3,1:end));
    t2 = Z12*ts1(i)+Z23*ts3(i);
    
    ts1 = cat (2,t1,ts1);
    ts2 = cat (2,t2,ts2);
    ts3 = cat (2,t3,ts3); 
    %vpoet teplot theta1, theta2, theta3 pozdl vmennka tepla v RS
    for(i=2:1:n+1)
       f1(i-1) = -(b1/T1)*ts1(i) + (a1/T1)*ts1(i-1) + (1/T1)*ts2(i);
       f2(i-1) = (Z12/T2)*ts1(i) - (1/T2)*ts2(i) + (Z23/T2)*ts3(i);
       f3(i-1) = -(b3/T3)*ts3(i) + (a3/T3)*ts3(i-1) + (1/T3)*ts2(i);
    end
    F=[f1;f2;f3];
else
    error('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
%==========================================================================
