%==========================================================================
% TRVTSS - S-Function, pouvan v simulinkovom bloku TROJKAPACITNY RURKOVY
% VYMENNIK TEPLA - SUPRUDOVY, ktor pota teploty vntorneho, vonkajieho
% mdia a steny rrky pre jednotliv asti vmennka uren diskretizciou
% v neustlenom t.j. dynamickom stave.
% Pouva funkcie: - TRVTS1.m 
%                  - TRVTS2.m 
%                  - TRVTS4.m 
%                  - TRVTS5.m 
% vstupn parametre:
%       t1 - teplota mdia na vstupe do vntornej rrky vmennka tepla,
%            t.j. theta1(0). Rozmer (1 x 1) 
%       t3 - teplota mdia na vstupe do vonkajej rrky vmennka tepla,
%            t.j. theta3(0). Rozmer (1 x 1)
%       l  - dlka vmennka tepla. Rozmer (1 x 1)
%       n  - poet sekov pri diskretizcii. Rozmer (1 x 1)
%       d1 - priemer vntornej rrky. Rozmer (1 x 1)
%       d3 - priemer vonkajej rrky. Rozmer (1 x 1)
%       h  - hrbka steny rrky. Rozmer (1 x 1)
%       m1 - hmotnostn tok mdia vo vntornej rrke. Rozmer (1 x 1)
%       m3 - hmotnostn tok mdia vo vonkajej rrke. Rozmer (1 x 1)
%       ro - vektor hustt. Rozmer (1 x 3), priom jednotliv prvky
%            zodpovedaj:   - ro(1) - hustota mdia vo vntornej rrke
%                           - ro(2) - hustota steny rrky
%                           - ro(3) - hustota mdia vo vonkajej rrke     
%       cp - vektor pecifickch tepelnch kapact. Rozmer (1 x 3), priom
%            jednotliv prvky vektora zodpovedaj:
%              cp(1) - pecifick tepeln kapacita mdia vo vntornej rrke
%              cp(2) - pecifick tepeln kapacita steny rrky
%              cp(1) - pecifick tepeln kapacita mdia vo vonkajej rrke
%       ka - vektor koeficientov prestupu tepla. Rozmer (1 x 2), priom
%            jednotliv prvky vektora zodpovedaj:
%               ka(1) - koeficient prestupu tepla prdenm zo steny rrky
%                       do mdia vo vntornej rrke
%               ka(2) - koeficient prestupu tepla prdenm z mdia vo
%                       vonkajej rrke do steny rrky
%       vst -  vektor aknch velin, ktor nadobda hodnoty 0 - 1 a jeho
%              rozmer je (1 x 4) t.j. [m1 m3 t1 t3]
%                   0 = ak nie je dan veliina akn - riadiaca
%                   1 = ak je dan veliina akn - riadiaca
%       por -  vektor poruchovch velin, ktor nadobda hodnoty 0 - 1 a
%              jeho rozmer je (1 x 4) t.j. [m1 m3 t1 t3]
%                   0 = ak nie je dan veliina poruchov
%                   1 = ak je dan veliina akn - poruchov
%       C - matica C - matica vstupu - vytvoren pomocou funkcie TRVTS4
% vstupn parametre - as mdlOutputs 
%       sys = vystup - teploty prisluchajce jednotlivm astiam a mdiam
%=========================================================================


function [sys,x0,str,ts] = TRVTSS(t,x,u,flag,vst,por,t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka,C)
switch flag,
  % Initialization %
    case 0,
    [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,vst,por,t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka,C);
  % Derivatives %
    case 1,
    sys=mdlDerivatives(t,x,u,vst,por,t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka,C);
  % Update %
    case 2,
    sys=mdlUpdate(t,x,u);
  % Outputs %
    case 3,
    sys=mdlOutputs(t,x,u,C);
  % GetTimeOfNextVarHit %
    case 4,
    sys=mdlGetTimeOfNextVarHit(t,x,u);
  % Terminate %
    case 9,
    sys=mdlTerminate(t,x,u);
  % Unexpected flags %
    otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

%=============================================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the S-function.
%=============================================================================

function [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,vst,por,t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka,C)

% urenie potu vstupov
[r,p]=size(C);

% urenie potu vstupov
in=cat(2,vst,por);
input=length(find(in));

sizes = simsizes;

sizes.NumContStates  = 3*n;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = r;
sizes.NumInputs      = input;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
% vpoet matice teplt jednotlivch mdii pozdl vmennka tepla pre seky
% uren diskretizciou v ustlenom - rovnovnom stave
    TS1= TRVTS1(t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka);
% prevedenie matice na vektor   
    ts2=TS1';
    for(i=1:1:n)
        for(j=1:1:3)
            TS(j+(i-1)*3)=ts2(i,j);
        end
    end
x0 = TS;

str = [];
ts  = [0 0];

%=============================================================================
% mdlDerivatives
% Return the derivatives for the continuous states.
%=============================================================================

function sys=mdlDerivatives(t,x,u,vst,por,t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka,C)

% priradenie aknch a poruchovch velin jednotlivm premennm
    [m11,m31,t11,t31]=TRVTS5(vst,por,u,m1,m3,t1,t3);
% vpoet derivcii teplt jednotlivch mdii pozdl vmennka tepla pre seky
% uren diskretizciou v dynamickom stave
    T = TRVTS2(x,t11,t31,l,n,d1,d3,h,m11,m31,ro,cp,ka);
% prevedenie matice na vektor
    ts2=T';
    for(i=1:1:n)
        for(j=1:1:3)
           TS(j+(i-1)*3)=ts2(i,j);
        end
    end
    sys = TS;

    
%=============================================================================
% mdlUpdate
% Handle discrete state updates, sample time hits, and major time step
% requirements.
%=============================================================================

function sys=mdlUpdate(t,x,u)
	sys = [];

%=============================================================================
% mdlOutputs
% Return the block outputs.
%=============================================================================
    
function sys=mdlOutputs(t,x,u,C)
% urenie vstupnch velin - ktor sa bud sledova
[rr,cc]=size(C);
    for(i=1:1:rr)
        for(j=1:1:cc)
            if(C(i,j)~=0)
                vystup(i)=x(j);
            end
        end
    end
 % vstupn veliiny
    sys=vystup';

%=============================================================================
% mdlTerminate
% Perform any end of simulation tasks.
%=============================================================================

function sys=mdlTerminate(t,x,u)
	sys = [];

%=============================================================================
