function A = TRVTS_A(l,n,d1,d3,h,m1,m3,ro,cp,ka)
%==========================================================================
% TRVTS_A - funkcia, ktor vypota maticu A v ustlenom (rovnovnom)
% stave. Funkcia je vytvren pre maticov tvar modelu trojkapacitnho
% sprudovho rrokovho vmennka tepla  a je pouit v m-file TRVTS_M.
% vstupn parametre:
%       l  - dlka vmennka tepla. Rozmer (1 x 1)
%       n  - poet sekov pri diskretizcii. Rozmer (1 x 1)
%       d1 - priemer vntornej rrky. Rozmer (1 x 1)
%       d3 - priemer vonkajej rrky. Rozmer (1 x 1)
%       h  - hrbka steny rrky. Rozmer (1 x 1)
%       m1 - hmotnostn tok mdia vo vntornej rrke. Rozmer (1 x 1)
%       m3 - hmotnostn tok mdia vo vonkajej rrke. Rozmer (1 x 1)
%       ro - vektor hustt. Rozmer (1 x 3), priom jednotliv prvky
%            zodpovedaj:   - ro(1) - hustota mdia vo vntornej rrke
%                           - ro(2) - hustota steny rrky
%                           - ro(3) - hustota mdia vo vonkajej rrke     
%       cp - vektor pecifickch tepelnch kapact. Rozmer (1 x 3), priom
%            jednotliv prvky vektora zodpovedaj:
%              cp(1) - pecifick tepeln kapacita mdia vo vntornej rrke
%              cp(2) - pecifick tepeln kapacita steny rrky
%              cp(1) - pecifick tepeln kapacita mdia vo vonkajej rrke
%       ka - vektor koeficientov prestupu tepla. Rozmer (1 x 2), priom
%            jednotliv prvky vektora zodpovedaj:
%               ka(1) - koeficient prestupu tepla prdenm zo steny rrky
%                       do mdia vo vntornej rrke
%               ka(2) - koeficient prestupu tepla prdenm z mdia vo
%                       vonkajej rrke do steny rrky
%vstupn parametre:
%       A - matica A - matica systmu
%==========================================================================

% test sprvneho zadania vstupnch parametrov
if nargin == 10
    % priradenie premennych
    ro1 = ro(1);    ro2 = ro(2);    ro3 = ro(3);
    cp1 = cp(1);    cp2 = cp(2);    cp3 = cp(3);    
    alfa12 = ka(1);    alfa23 = ka(2);
    % vpoet kontnt V1, V3, A12, A23, S12, S23, q1, q3, dz
    d2 = d1+2*h;        dz = l/n;
    q1 = m1/(ro1);    q3 = m3/(ro3);
    S1 = (pi*(d1^2))/4;
    S2 = (pi*(d2^2-d1^2))/4;
    S3 = (pi*(d3^2-d2^2))/4;
    V1 = S1;    V2 = S2;    V3 = S3;
    A12 = pi*d1;    A23 = pi*d2;
    
    % vpoet kontnt T1, w1;
    T1 = (ro1*cp1*V1)/(alfa12*A12);
    w1 = q1/S1;
    % vpoet kontnt T2, Z12, Z23;
    T2 = (ro2*cp2*V2)/(alfa12*A12+alfa23*A23);
    Z12= (alfa12*A12)/(alfa12*A12+alfa23*A23);
    Z23= (alfa23*A23)/(alfa12*A12+alfa23*A23);    
    % vpoet kontnt T1, w1;
    T3 = (ro3*cp3*V3)/(alfa23*A23);
    w3 = q3/S3;
    
    % vpoet kontnt a1, b1
    a1 = (T1*w1)/dz;
    b1 = ((T1*w1)/dz +1);
    % vpoet kontnt a3, b3
    a3 = (T3*w3)/dz;
    b3 = ((T3*w3)/dz +1);
    
    % matica A
    % prv 3 riadky
    for(i=1:1:3)
        for(j=1:1:3*n)
            if i==1
                if(j==i | j==i+1)
                    if j==i
                        A(i,j)=(-b1/T1);
                    else
                        A(i,j)=(1/T1);
                    end
                else
                    A(i,j)=0;
                end
            end
            if i==2
                if(j==i | j==i-1 | j==i+1)
                    if j==i-1
                        A(i,j)=(Z12/T2);
                    end
                    if j==i      
                        A(i,j)=(-1/T2);
                    end
                    if j==i+1
                        A(i,j)=(Z23/T2);
                    end
                else
                    A(i,j)=0;
                end
            end
            if i==3
                if(j==i | j==i-1)
                    if j==i-1      
                        A(i,j)=(1/T3);
                    else
                        A(i,j)=(-b3/T3);
                    end
                else
                    A(i,j)=0;
                end
            end
        end
    end      
    % ostatne riadky pre T(1,i)
    for(i=4:3:3*n)    
        for(j=1:1:3*n)
            if(i==j | j==i-3 | j==i+1)
                if(i==j)
                    A(i,j)=(-b1/T1);
                end
                if(j==i-3)
                    A(i,j)=(a1/T1);
                end
                if(j==i+1)
                    A(i,j)=(1/T1);
                end
            else
                A(i,j)=0;
            end
        end
    end
    for(i=5:3:3*n)    
        for(j=1:1:3*n)
            if(i==j | j==i-1 | j==i+1)
                if(i==j)
                    A(i,j)=(-1/T2);
                end
                if(j==i-1)
                    A(i,j)=(Z12/T2);
                end
                if(j==i+1)
                    A(i,j)=(Z23/T2);
                end                
            else
                A(i,j)=0;
            end
        end
    end
    for(i=6:3:3*n)         
        for(j=1:1:3*n)
            if(i==j | j==i-3 | j==i-1)
                if(i==j)
                    A(i,j)=(-b3/T3);
                end
                if(j==i-3)
                    A(i,j)=(a3/T3);
                end
                if(j==i-1)
                    A(i,j)=(1/T3);
                end
            else
                A(i,j)=0;
            end
        end
    end
else
    error('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
%==========================================================================
                
                
                
    
