%==========================================================================
% TRVTS - m-file vytvoren pre systm trojkapacitn sprudov rrkov 
% vmennk tepla. Na zklade zadanch vstupnch parametrov pre jednotliv
% funkcie s vypotan zodpovedajce hodnoty.
% pouit funkcie:
%   TS = TRVTS1(t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka)
%      - vpoet matice teplt. Rozmer (3 x n), kde riadok zodpoved
%        prslunej teplote a stlpec prslunmu seku pri diskretizcii.
%        Tvar matice TS = [TS1; TS2; TS3], kde:
%            TS1 - vektor teplt mdia vo vntornej rrke pozdl vmennka 
%                  tepla pre jednotliv seky diskretizcie.
%            TS2 - vektor teplt steny rrky pozdl vmennka tepla pre
%                  jednotliv seky diskretizcie.
%            TS3 - vektor teplt mdia vo vonkajej rrke pozdl vmennka
%                  tepla pre jednotliv seky diskretizcie.
%   A = TRVTS_A(l,n,d1,d3,h,m1,m3,ro,cp,ka)
%     - generovanie matice A - matice systmu
%   B = TRVTS_B(l,n,d1,d3,h,m1,m3,ro,cp,ka,pom)
%     - generovanie matice B - matice riadenia
%   C = TRVTS_C(n,vystup)       - generovanie matice C - matice vstupu
%   D = TRVTS_D(B,C)            - generovanie matice D
%   ts = TRVTS3(TS,C,n);
%      - vytvorenie vektora sledovanch teplt pre jednotliv seky
%        vmennka prislchajce jednotlivm premennm.
% vstupn parametre:
%       t1 - teplota mdia na vstupe do vntornej rrky vmennka tepla,
%            t.j. theta1(0). Rozmer (1 x 1) 
%       t3 - teplota mdia na vstupe do vonkajej rrky vmennka tepla,
%            t.j. theta3(0). Rozmer (1 x 1)
%       l  - dlka vmennka tepla. Rozmer (1 x 1)
%       n  - poet sekov pri diskretizcii. Rozmer (1 x 1)
%       d1 - priemer vntornej rrky. Rozmer (1 x 1)
%       d3 - priemer vonkajej rrky. Rozmer (1 x 1)
%       h  - hrbka steny rrky. Rozmer (1 x 1)
%       m1 - hmotnostn tok mdia vo vntornej rrke. Rozmer (1 x 1)
%       m3 - hmotnostn tok mdia vo vonkajej rrke. Rozmer (1 x 1)
%       ro - vektor hustt. Rozmer (1 x 3), priom jednotliv prvky
%            zodpovedaj:   - ro(1) - hustota mdia vo vntornej rrke
%                           - ro(2) - hustota steny rrky
%                           - ro(3) - hustota mdia vo vonkajej rrke     
%       cp - vektor pecifickch tepelnch kapact. Rozmer (1 x 3), priom
%            jednotliv prvky vektora zodpovedaj:
%              cp(1) - pecifick tepeln kapacita mdia vo vntornej rrke
%              cp(2) - pecifick tepeln kapacita steny rrky
%              cp(1) - pecifick tepeln kapacita mdia vo vonkajej rrke
%       ka - vektor koeficientov prestupu tepla. Rozmer (1 x 2), priom
%            jednotliv prvky vektora zodpovedaj:
%               ka(1) - koeficient prestupu tepla prdenm zo steny rrky
%                       do mdia vo vntornej rrke
%               ka(2) - koeficient prestupu tepla prdenm z mdia vo
%                       vonkajej rrke do steny rrky
%       vstup - vektor sledovanch velin, ktor nadobda hodnoty 0 - 1
%                a jeho rozmer je (1 x 3n) t.j. [.. T1(i) T2(i) T3(i) ..]
%                   0 = ak nechceme dan veliinu mera - vykresli
%                   1 = ak chceme dan veliinu mera - vykresli
%       pom - vektor zskan stanm vektora vst a por
% vstupn parametre:
%       TS - matica teplt. Rozmer (3 x n), kde riadok zodpoved prslunej
%            teplote a stlpec prslunmu seku pri diskretizcii. Tvar
%            matice TS = [TS1; TS2; TS3], kde:
%               TS1 - vektor teplt mdia vo vntornej rrke pozdl vmennka 
%                     tepla pre jednotliv seky diskretizcie.
%               TS2 - vektor teplt steny rrky pozdl vmennka tepla pre
%                     jednotliv seky diskretizcie.
%               TS3 - vektor teplt mdia vo vonkajej rrke pozdl vmennka
%                     tepla pre jednotliv seky diskretizcie.
%       A - matica systmu 
%       B - matica riadenia
%       C - matica vstupu
%       D - matica 
%       ts - ts vektor  sledovanch  teplt v  jednotlivch astiach 
%            vmennka tepla v ustlenom stave, t.j. 
%                   ts = [ts1(i) ts2(i) ts3(i)..]
%       x0 - transponovan vektor vektora ts
%==========================================================================


cc = find(pom);
for (i=1:1:length(cc))
    if(cc(i)==1)
        TT(i)=t1;
    end
    if(cc(i)==2)
        TT(i)=t3;
    end
end
%vygenerovanie jednotlivch parametrov pre linearizovan model
TS = TRVTS1(t1,t3,l,n,d1,d3,h,m1,m3,ro,cp,ka);
A = TRVTS_A(l,n,d1,d3,h,m1,m3,ro,cp,ka);
B = TRVTS_B(l,n,d1,d3,h,m1,m3,ro,cp,ka,pom);
C = TRVTS_C(n,vystup);
D = TRVTS_D(B,C);  
ts = TRVTS3(TS,C,n);
x0 = ts';
%==========================================================================

