%==========================================================================
% KOLONA_X - S-Function, pouvan v simulinkovom bloku ETAZOVA REKTIFIKACNA
% KOLONA, ktor pota molov zlomky (zloenie) kvapalnej fzy na 
% jednotlivch etach v neustlenom t.j dynamickom stave.
% Pouva funkcie: - kolona1.m 
%                  - kolona2.m  
%                  - kolona3.m
%                  - kolona4.m
% Poznmka:
% Cslovanie eti je od hlavy kolony po ptu kolony, priom kondenztor je
% nult et a nark je n+1 et.
% vstupn parametre: 
%       N - poet eti kolony - nie je zapotan vark a kondenztor
%       F - nstrekov et
%       axb - koeficienty rovnovnej krivky
%           - krivka m tvar
%                                ax^2 + bx + c
%                           y = ---------------
%                                dx^2 + ex + c           
%       nii - innos varka a jednotlivch eti.  Hodnoty treba zadva
%             v percentch. Rozmer vektora me by 1x2 alebo 1x(n+2).
%               1x2 - ak je innos eti rovnak, potom tvar vektora je
%                     [innos eti, innos varka]
%               1x(n+2) - ak s innosti eti rzne, potom tvar vektoraje
%                         [.. innos i-tej ete .. innos varka] 
%       nF - tok ltkovho mnostva privdzanho nstreku
%       xF - molov zlomok (zloenie) privdzanho nstreku
%       nD - tok ltkovho mnostva destiltu
%       nL - tok ltkovho mnostva sptnho toku
%       nV - tok ltkovho mnostva pr odchdzajcich z hlavy kolony
%       nW - tok ltkovho mnostva destilnho zvyku
%       H  - zdre kvapaliny na jednotlivch etach a vo varku. Rozmer
%            vektora me by 1x2 alebo 1x(n+2).
%               1x2 - ak s zdre kvapaliny na jednotlivch etach rovnak
%               1x(n+1) - ak s zdre kvapaliny na jednotlivch etach 
%                         rzne.
%       C - matica C - matica vstupu - vytvoren pomocou funkcie KOLONA4
%       vst -  vektor aknch velin, ktor nadobda hodnoty 0 - 1 a jeho
%              rozmer je (1 x 6) t.j. [nF  xF  nL  nD  nV  nW]
%                   0 = ak nie je dan veliina akn - riadiaca
%                   1 = ak je dan veliina akn - riadiaca
%       por -  vektor poruchovch velin, ktor nadobda hodnoty 0 - 1 a
%              jeho rozmer je (1 x 6) t.j. [nF  xF  nL  nD  nV  nW]
%                   0 = ak nie je dan veliina poruchov
%                   1 = ak je dan veliina akn - poruchov
% vstupn parametre - as mdlOutputs 
%       sys=vystup' - sledovan veliiny t.j. zloenie kvapalnej fzy na 
%                     jednotlivch etach. Vstupn veliiny zvisia od 
%                     tvaru vektora sledovanch velin. Rozmer (1 x n+2).
%                     Nadobda hodnoty 1 - 0.
%                           1 - ak dan veliinu chceme sledova
%                           0 - ak dan veliinu nechceme sledova
%=========================================================================


function [sys,x0,str,ts] = kolona_x(t,x,u,flag,N,F,axb,nii,nF,xF,nD,nL,nV,nW,H,C,vst,por)
switch flag,
  % Initialization %
    case 0,
    [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,N,F,axb,nii,nF,xF,nD,nL,nV,nW,H,C,vst,por);
  % Derivatives %
    case 1,
    sys=mdlDerivatives(t,x,u,N,F,axb,nii,nF,xF,nD,nL,nV,nW,H,C,vst,por);
  % Update %
    case 2,
    sys=mdlUpdate(t,x,u);
  % Outputs %
    case 3,
    sys=mdlOutputs(t,x,u,C);
  % GetTimeOfNextVarHit %
    case 4,
    sys=mdlGetTimeOfNextVarHit(t,x,u);
  % Terminate %
    case 9,
    sys=mdlTerminate(t,x,u);
  % Unexpected flags %
    otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

%=============================================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the S-function.
%=============================================================================

function [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,N,F,axb,nii,nF,xF,nD,nL,nV,nW,H,C,vst,por)

aa=find(vst);
bb=find(por);
% urenie potu vstupnch parametrov t.j. aknch - riadiacich velin
input=length(aa)+length(bb);

% urenie potu vstupnch parametrov t.j. sledovanch velin
[rr,cc]=size(C);
output = rr;
%urenie potu stavovch velin - N - poet eti + vark + kondenztor
n=N+2;

sizes = simsizes;

sizes.NumContStates  = n;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = output;
sizes.NumInputs      = input;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);

% vpoet molovch zlomkov (zloenia) na jednotlivch etach v ustlenom stave
x0=kolona2(N,F,axb,nii,nF,xF,nL,nD,nV,nW,H);

str = [];

ts  = [0 0];

%=============================================================================
% mdlDerivatives
% Return the derivatives for the continuous states.
%=============================================================================

function sys=mdlDerivatives(t,x,u,N,F,axb,nii,nF,xF,nD,nL,nV,nW,H,C,vst,por)

% priradenie aknch a poruchovch velin jednotlivm premennm
    [nF1,xF1,nL1,nD1,nV1,nW1]=kolona3(vst,por,u,nF,xF,nL,nD,nV,nW);
% vpoet zmien molovch zlomkov (zloenia) na jednotlivch etach v neustlenom stave
    sys = kolona1(x,N,F,axb,nii,nF1,xF1,nL1,nD1,nV1,nW1,H);
    
%=============================================================================
% mdlUpdate
% Handle discrete state updates, sample time hits, and major time step
% requirements.
%=============================================================================

function sys=mdlUpdate(t,x,u)
	sys = [];

%=============================================================================
% mdlOutputs
% Return the block outputs.
%=============================================================================
    
function sys=mdlOutputs(t,x,u,C)
% urenie vstupnch velin - molovch zlomkov, ktor sa bud sledova
[rr,cc]=size(C);
    for(i=1:1:rr)
        for(j=1:1:cc)
            if(C(i,j)~=0)
                vystup(i)=x(j);
            end
        end
    end
 % vstupn veliiny
    sys=vystup';

%=============================================================================
% mdlTerminate
% Perform any end of simulation tasks.
%=============================================================================

function sys=mdlTerminate(t,x,u)
	sys = [];

%=============================================================================
