function A = matica_A(h,a,d,e,f)
%==========================================================================
% MATICA_A - funkcia ktor vypota maticu A v ustlenom (rovnovnom)
% stave. Funkcia je vytvoren pre linerizoan matematick model zsobnkov
% kvapaliny a je pouvan v m-file MATICA.M.
% vstupn parametre:
%       h - vektor vok hladn v ustlenom stave v jednotlivch
%           zsobnkoch kvapaliny [hs1,hs2,...,hsn]. Rozmer (1 x n)
%       a - poet zsobnkov
%       d - vektor interakcii
%               d(i) = 1 - ak je interakcia medzi i-tym a (i+1) zsobnkom
%                          kvapaliny
%               d(i) = 0 - ak nie je interakcia medzi i-tym a (i+1)
%                          zsobnkom kvapaliny
%               rozmer (1 x n).
%       e - vektor kontnt (charakteristk) ventilov [k11,k22,...,kn] pre
%           jednotliv zsobnky kvapaliny. Rozmer (1 x n).
%       f - plochy prierezov zsobnkov kvapaliny [F1,F2,...,Fn],
%           rozmer (1 x n)
%vstupn parametre:
%       A - matica A - matica systmu
%==========================================================================

%test spravneho poctu vstupnych parametrov:
if nargin==5
%test i nastala interakcia;
    bb = find(d);
    if(length(bb)>0)
        b=1;
    else
        b=0;
    end
    %test pre spravne zadanie interakcie:
    if (b==0 | b==1)
        %priradenie premennych a dlzky vektorov
        p_zasobnikov=a;
        p_int=length(d);
        p_ventilov=length(e);
        p_prierezy=length(f);
        n=p_zasobnikov;
        %priradenie premennych
        for (i=1:1:p_zasobnikov)
            k(i)=e(i);
            F(i)=f(i);
            hs(i)=h(i);
        end
        %bez interakcie
        if(b==0)
            for (i=1:1:n)
                for(j=1:1:n)
                    if i==j | (j==i-1 & j~=0)
                        if i==j         
                            K(i)=k(i)/(2*sqrt(hs(i)));
                            A(i,j)=-K(i)/F(j);
                        else
                            K(i)=k(i)/(2*sqrt(hs(i)));
                            A(i,j)=K(j)/F(i);
                        end
                    else
                        A(i,j)=0;
                    end
                end
            end  
        %s interakciou
        else
            %prvy riadok matice A
            i=1;
                for (j=1:1:n)
                    if(d(i)==0)
                        if (i==j | j==i+1)
                            if (i==j)
                                K(i)=k(i)/(2*(sqrt(hs(i))));
                                A(i,j)=-K(i)/F(i);
                            else
                                A(i,j)=0;
                            end
                        else
                            A(i,j)=0;
                        end
                    else
                        if (i==j | j==i+1)
                            if (i==j)
                                K(i)=k(i)/(2*sqrt(hs(i)-hs(i+1)));
                                A(i,j)=-K(i)/F(i);
                            else
                                K(i)=k(i)/(2*sqrt(hs(i)-hs(i+1)));
                                A(i,j)=K(i)/F(i);
                            end
                        else
                            A(i,j)=0;
                        end
                    end
                end
            %druhy az n-1 riadok matice A
            for (i=2:1:n)
                for (j=1:1:n)
                    if (d(i)==0) % nie je interakcia
                        if(d(i-1)==0) % nebola interakcia
                            if (i==j | j==i-1 | j==i+1)
                                if(i==j)
                                    K(i)=k(i)/(2*sqrt(hs(i)));
                                    A(i,j)=-K(i)/F(i);
                                end
                                if(j==i-1)
                                    K(i-1)=k(i-1)/(2*sqrt(hs(i-1)));
                                    A(i,j)=K(i-1)/F(i);
                                end
                                if(j==i+1)
                                    A(i,j)=0;
                                end
                            else
                                A(i,j)=0;
                            end
                        else    % nie je interakcia ale bola inteakcia.
                            if (i==j | j==i-1 | j==i+1)
                                if(i==j)
                                    K(i)=k(i)/(2*sqrt(hs(i)));
                                    K(i-1)=k(i-1)/(2*sqrt(hs(i-1)-hs(i)));
                                    A(i,j)=-(K(i)/F(i)+K(i-1)/F(i));
                                end
                                if(j==i-1)
                                    K(i-1)=k(i-1)/(2*sqrt(hs(i-1)-hs(i)));
                                    A(i,j)=K(i-1)/F(i);
                                end
                                if(j==i+1)
                                    A(i,j)=0;
                                end
                            else
                                A(i,j)=0;
                            end 
                        end
                    else    %je interakcia 
                        if(d(i-1)==0)   %nebola interakcia
                            if (i==j | j==i-1 | j==i+1)
                                if(i==j)
                                    K(i)=k(i)/(2*sqrt(hs(i)-hs(i+1)));
                                    A(i,j)=-K(i)/F(i);
                                end
                                if(j==i-1)
                                    K(i-1)=k(i-1)/(2*sqrt(hs(i-1)));
                                    A(i,j)=K(i-1)/F(i);
                                end
                                if(j==i+1)
                                    K(i)=k(i)/(2*sqrt(hs(i)-hs(i+1)));
                                    A(i,j)=K(i)/F(i);
                                end
                            else
                                A(i,j)=0;
                            end
                        else    %je interakcia a bola interakcia
                            if (i==j | j==i-1 | j==i+1)
                                if(i==j)
                                    K(i)=k(i)/(2*sqrt(hs(i)-hs(i+1)));
                                    K(i-1)=k(i-1)/(2*sqrt(hs(i-1)-hs(i)));
                                    A(i,j)=-(K(i)/F(i)+K(i-1)/F(i));
                                end
                                if(j==i-1)
                                    K(i-1)=k(i-1)/(2*sqrt(hs(i-1)-hs(i)));
                                    A(i,j)=K(i-1)/F(i);
                                end
                                if(j==i+1)
                                    K(i)=k(i)/(2*sqrt(hs(i)-hs(i+1)));
                                    A(i,j)=K(i)/F(i);
                                end
                            else
                                A(i,j)=0;
                            end 
                        end
                    end
                end
            end
            %posledny riadok matice A
            i=n;
                for (j=1:1:n)
                    if (d(i)==0)
                        if (d(i-1)==0) %nebola interakcia
                            if (i==j | j==i-1)
                                if (i==j)
                                    K(i)=k(i)/(2*sqrt(hs(i)));
                                    A(i,j)=-K(i)/F(i);
                                else
                                    K(i-1)=k(i-1)/(2*sqrt(hs(i-1)));
                                    A(i,j)=K(i-1)/F(i);
                                end
                            else
                                A(i,j)=0;
                            end
                        else    %bola interakcia
                            if (i==j | j==i-1)
                                if (i==j)
                                    K(i)=k(i)/(2*sqrt(hs(i)));
                                    K(i-1)=k(i-1)/(2*sqrt(hs(i-1)-hs(i)));
                                    A(i,j)=-(K(i-1)/F(i)+K(i)/F(i));
                                else
                                    K(i-1)=k(i-1)/(2*sqrt(hs(i-1)-hs(i)));
                                    A(i,j)=K(i-1)/F(i);
                                end
                            else
                                A(i,j)=0;
                            end
                        end
                    else
                        error ('ZLE ZADANY VEKTOR INTERAKCII')
                    end
                end
            end
    else
        error ('NESPRAVNE ZADANA INTERAKCIA')
    end
else
    error ('NESPRAVNY POCET VSTUPNYCH PARAMETROV')
end

%==========================================================================