function K = pl_vymenniky1(x,qv,tv,tp,V,ro,cp,alfa,F,n)
%==========================================================================
% PL_VYMENNIKY1 - funkcia vytvoren pre systm n-pl᚝ovch vmennkov
% tepla zapojench za sebou, priom ohrevn mdium je nasten para pri
% teplote varu, ktor odovzd len kondenzan teplo a jej teplota sa
% nemen. Stavovmi veliinami s teploty v jednotlivch vmennkoch tepla.
% Funkcia generuje na zklade zadanch vstupnch parametrov vektor
% zvislost zmien teploty v jednotlivch vmennkov od asu a transponuje
% vektor do vstupnej premennej K. Premenn K je nasledovne vyuvan vo
% funkcii PL_VYMENNIKY2 a v s-funkcii PL_VYMENNIKY_P. 
% Vstupn parametre:
%    x  - generovan teplota v jednotlivch vymennkoch - odhad teploty
%    qv - vektor vstupnch prietokov kvapaliny do jednotlivch vmennkov 
%         tepla. Rozmer (1 x n)
%    tv - vektor vstupnch teplot do jednotlivch vmennkov tepla. Rozmer
%         (1 x n).
%    tp - teplota pary. Rozmer (1 x 1)
%    V  - vektor objemov jednotlivch vmennkov tepla. Rozmer (1 x n).
%    ro - hustota kvapaliny - ohrievanho mdia - priemern hodnota z
%         danho teplotnho intervalu. Rozmer (1x1)
%    cp - pecifick tepeln kapacita ohrievanho mdia - kvapaliny - 
%         priemerna hodnota z danho teplotnho intervalu. Rozmer (1x1)
%    alfa - koeficient prestupu tepla. Jeho rozmer zvis od uvatea a
%         me ma dva tvary. 
%           (1 x 1) - koeficienty s rovnak pre vetky vmennky tepla
%           (1 x n) - koeficienty s rzne pre jednotliv vmennky tepla.
%    F  - vektor teplovmennch plch jednotlivch vmennkov. 
%         Rozmer (1 x n)
%    n  - poet vmennkov tepla. Rozmer (1 x 1)
% Vstupn parametre:
%    K - transponovan vektor, ktor obsahuje zvislosti zmien teplt v
%        jednotlivch vmennkoch tepla od asu
%==========================================================================

%test sprvneho zadania potu vstupnch parametrov
if nargin == 10
    %priradenie premennych
    t=x;
    alfax=alfa;
    a=length(alfax);
    if (a == 1)     %alfa je rovnaka pre vsetky vymenniky
        for (i=1:1:n)
           alfa(i) = alfax;
       end
    else
       alfa = alfax;
    end
    tpx=tp;
    a=length(tpx);
    if (a == 1)     %tp je rovnaka pre vsetky vymenniky
        for (i=1:1:n)
           tp(i) = tpx;
       end
    else
       tp = tpx;
    end

    %tvar rovnice pre prvy vymennik  
    q(1) = qv(1);
    k(1) = -((q(1)*ro*cp)/(V(1)*ro*cp))*t(1) + ((qv(1)*ro*cp)/(V(1)*ro*cp))*tv(1) + ((alfa(1)*F(1))/(V(1)*ro*cp))*(tp(1)-t(1));

    %tvar rovnice pre 2-n vymennik  T(i)*dt(i)/dt = -t(i) + T(i-1)*t(i-1) + Z(i)*tp(i) + X(i)*tv(i)
    for (i=2:1:n)
        q(i) = qv(i) + q(i-1);
        tpr(i) = (qv(i)*tv(i)+q(i-1)*t(i-1))/(qv(i)+q(i-1));
        k(i) = -((q(i)*ro*cp)/(V(i)*ro*cp))*t(i) + ((qv(i)*ro*cp)/(V(i)*ro*cp))*tv(i) + ((alfa(i)*F(i))/(V(i)*ro*cp))*(tp(i)-tpr(i)) + ((q(i-1)*ro*cp)/(V(i)*ro*cp))*t(i-1);
    end
    K=k';
else
    error('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
%==========================================================================
