function K = pl_vymenniky5(x,qv,tv,Q,V,ro,cp,n)
%==========================================================================
% PL_VYMENNIKY5 - funkcia vytvoren pre systm n-vmennkov tepla
% ohrievanch pomocou uritho zdroja zapojench za sebou, priom ohrevn
% mdium je teplo, ktor je do systmu dodvan, i pouitm elektrickho
% ohrevu, ponornm hadom atd. Stavovmi veliinami s teploty v jednotlivych
% vymennikoch tepla. Funkcia generuje na zklade zadanch vstupnch 
% parametrov vektor zvislost zmien teploty v jednotlivch vmennkov od 
% asu a transponuje vektor do vstupnej premennej K. Premenn K je 
% nasledovne vyuvan vo funkcii PL_VYMENNIKY2 a v s-funkcii PL_VYMENNIKY_O. 
% Vstupn parametre:
%    x  - generovan teplota v jednotlivch vymennkoch - odhad teploty
%    qv - vektor vstupnch prietokov kvapaliny do jednotlivch vmennkov 
%         tepla. Rozmer (1 x n)
%    tv - vektor vstupnch teplot do jednotlivch vmennkov tepla. Rozmer
%         (1 x n).
%    Q  - teplo, ktor je do sstavy dodan od uritho zdroja. Rozmer (1 x 1)
%    V  - vektor objemov jednotlivch vmennkov tepla. Rozmer (1 x n).
%    ro - hustota kvapaliny - ohrievanho mdia - priemern hodnota z
%         danho teplotnho intervalu. Rozmer (1x1)
%    cp - pecifick tepeln kapacita ohrievanho mdia - kvapaliny - 
%         priemerna hodnota z danho teplotnho intervalu. Rozmer (1x1)
%    n  - poet vmennkov tepla. Rozmer (1 x 1)
% Vstupn parametre:
%    K - transponovan vektor, ktor obsahuje zvislosti zmien teplt v
%        jednotlivch vmennkoch tepla od asu
%==========================================================================

%test sprvneho zadania potu vstupnch parametrov
if nargin == 8
    %priradenie premennych
    t=x;
    Qx=Q;
    a=length(Qx);
    if (a == 1)     %Q je rovnaka pre vsetky vymenniky
        for (i=1:1:n)
           Q(i) = Qx;
       end
    else
       Q = Qx;
    end

    %tvar rovnice pre prvy vymennik  
    q(1) = qv(1);
    k(1) = -((q(1)*ro*cp)/(V(1)*ro*cp))*t(1) + ((qv(1)*ro*cp)/(V(1)*ro*cp))*tv(1) + Q(1)/(V(1)*ro*cp);

    %tvar rovnice pre 2-n vymennik  T(i)*dt(i)/dt = -t(i) + T(i-1)*t(i-1) + Z(i)*tp + X(i)*tv(i)
    for (i=2:1:n)
        q(i) = qv(i) + q(i-1);
        k(i) = -((q(i)*ro*cp)/(V(i)*ro*cp))*t(i) + ((qv(i)*ro*cp)/(V(i)*ro*cp))*tv(i) + Q(i)/(V(i)*ro*cp) + ((q(i-1)*ro*cp)/(V(i)*ro*cp))*t(i-1);
    end
    K=k';
else
    error('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
%==========================================================================
