%==========================================================================
% ZASOBNIKY_NELIN - S-Function, pouvan v simulinkovom bloku PLASTOVE
% VYMENNIKY TEPLA - ohrevn medium para, ktor pota vky hladn v
% zsobnkoch kvapaliny v neustlenom t.j dynamickom stave. 
% Pouva funkcie: - pl_vymenniky1.m 
%                  - pl_vymenniky2.m 
%                  - pl_vymenniky3.m 
%                  - pl_vymenniky4.m 
% vstupn parametre: 
%    vst -  vektor aknch velin, ktor nadobda hodnoty 0 - 1 a jeho
%           rozmer je (1 x 2n+1) t.j. [Tp .. qvi .. Tvi ..]
%                   0 = ak nie je dan veliina akn - riadiaca
%                   1 = ak je dan veliina akn - riadiaca
%    por -  vektor poruchovch velin, ktor nadobda hodnoty 0 - 1 a
%           jeho rozmer je (1 x 2n+1) t.j. [Tp .. qvi .. Tvi ..]
%                   0 = ak nie je dan veliina poruchov
%                   1 = ak je dan veliina akn - poruchov
%    qv - vektor vstupnch prietokov kvapaliny do jednotlivch vmennkov 
%         tepla. Rozmer (1 x n)
%    tv - vektor vstupnch teplot do jednotlivch vmennkov tepla. Rozmer
%         (1 x n).
%    tp - teplota pary. Rozmer (1 x 1)
%    V  - vektor objemov jednotlivch vmennkov tepla. Rozmer (1 x n).
%    ro - hustota kvapaliny - ohrievanho mdia - priemern hodnota z
%         danho teplotnho intervalu. Rozmer (1x1)
%    cp - pecifick tepeln kapacita ohrievanho mdia - kvapaliny - 
%         priemerna hodnota z danho teplotnho intervalu. Rozmer (1x1)
%    alfa - koeficient prestupu tepla. Jeho rozmer zvis od uvatea a
%         me ma dva tvary. 
%           (1 x 1) - koeficienty s rovnak pre vetky vmennky tepla
%           (1 x n) - koeficienty s rzne pre jednotliv vmennky tepla.
%    F  - vektor teplovmennch plch jednotlivch vmennkov. 
%         Rozmer (1 x n)
%    n  - poet vmennkov tepla. Rozmer (1 x 1)
%    C - matica C - matica vstupu - vytvorena pomocou funkie PL_VYMENNIKY4
% vstupn parametre - as mdlOutputs 
%       sys = vystup - teploty kvapaliny v jednotlivch vmennkoch tepla
%                       v neustlenom - dynamickom stave
%=========================================================================


function [sys,x0,str,ts] = pl_vymenniky_p(t,x,u,flag,vst,por,qv,tv,tp,V,ro,cp,alfa,F,n,C)
switch flag,
  % Initialization %
    case 0,
    [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,vst,por,qv,tv,tp,V,ro,cp,alfa,F,n,C);
  % Derivatives %
    case 1,
    sys=mdlDerivatives(t,x,u,vst,por,qv,tv,tp,V,ro,cp,alfa,F,n,C);
  % Update %
    case 2,
    sys=mdlUpdate(t,x,u);
  % Outputs %
    case 3,
    sys=mdlOutputs(t,x,u,C);
  % GetTimeOfNextVarHit %
    case 4,
    sys=mdlGetTimeOfNextVarHit(t,x,u);
  % Terminate %
    case 9,
    sys=mdlTerminate(t,x,u);
  % Unexpected flags %
    otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

%=============================================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the S-function.
%=============================================================================

function [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,vst,por,qv,tv,tp,V,ro,cp,alfa,F,n,C)

% urenie potu vstupov
[r,p]=size(C);

% urenie potu vstupov
in=cat(2,vst,por);
input=length(find(in));

sizes = simsizes;

sizes.NumContStates  = n;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = p;
sizes.NumInputs      = input;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
% vpoet vok hladn v zsobnkoch kvapaliny v ustlenom stave

x0 = pl_vymenniky2(qv,tv,tp,V,ro,cp,alfa,F,n);

str = [];
ts  = [0 0];

%=============================================================================
% mdlDerivatives
% Return the derivatives for the continuous states.
%=============================================================================

function sys=mdlDerivatives(t,x,u,vst,por,qv,tv,tp,V,ro,cp,alfa,F,n,C)

% priradenie aknch a poruchovch velin jednotlivm premennm
    [tp1, qv1, tv1]=pl_vymenniky3(vst,por,u,tp,qv,tv,n);
  % vpoet zmien vok hladn v zsobnkoch kvapaliny v neustlenom stave
    sys = pl_vymenniky1(x,qv1,tv1,tp1,V,ro,cp,alfa,F,n);
    
%=============================================================================
% mdlUpdate
% Handle discrete state updates, sample time hits, and major time step
% requirements.
%=============================================================================

function sys=mdlUpdate(t,x,u)
	sys = [];

%=============================================================================
% mdlOutputs
% Return the block outputs.
%=============================================================================
    
function sys=mdlOutputs(t,x,u,C)
% urenie vstupnch velin - vok hladn, ktor sa bud sledova
[rr,cc]=size(C);
    for(i=1:1:rr)
        for(j=1:1:cc)
            if(C(i,j)~=0)
                vystup(j)=x(i);
            end
        end
    end
 % vstupn veliiny
    sys=vystup';

%=============================================================================
% mdlTerminate
% Perform any end of simulation tasks.
%=============================================================================

function sys=mdlTerminate(t,x,u)
	sys = [];

%=============================================================================
