function F= reaktor1 (x,a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k)
%==========================================================================
% REAKTOR1 - funkcia vytvoren pre systm prietokov chemick reaktor.
% Generuje na zklade zadanch vstupnch parametrov vektor zvislost zmien
% jednotlivch premennch (koncentrcie reaktantov, produktov, teplota
% reaknej zmesi, teplota chladiaceho mdia) od asu a transponuje ho do
% vstupnej premennej F. Premenn F je nsledovne vyuvan vo funkcii
% REAKTOR2.M. Funkciu mno vyui na rieenie jednoduchch reakci.
% Nemno ju vyui na rieenie postupnch reakci a systmov, kde prebieha
% viac ako tri chemick reakcie. Dalej ju nemono poui ak poet
% reaktantov je viac ako p.
% vstupn parametre 
%       x -  vektor velin, ktor s potrebn pre rieenie danej funkcie.
%            Je tvoren vo funkcii REAKTOR2.M a je zloen z vektorov
%            odhadnutch koncentrcii a teplt t.j. x=[c1 .. cn T Tc].
%       a  - poet reakci - maximlny poet - 3 chemick reakcie.
%       rp - poet reaktantov, ktor vystupuj v jednotlivch reakcich.
%            Maximlny poet reaktantov je p.
%       pp - poet produktov, ktor vystuj vo jednotlivch reakcich.
%       m  - matica stechiometrickch koeficientov pre vetky reakcie.
%            Riadky matice predstavuje reakciu a jednotliv stlpce
%            predstavuj reaktant, produkt v danej rovnici. Ak reaktant,
%            produkt nevystupuje v danej rovnici je dan prvok matice rovn
%            nule.
%       cv - vektor vstupnch koncentrcii
%       q  - vstupn prietok reaknej zmesi
%       qc - vstupn prietok chladiaceho mdia
%       Tv - vstupn teplota reaknej zmesi
%       Tvc- vstupn teplota chladiaceho mdia
%       kr - vektor rchlostnch kontnt
%       e  - vektor reaknch energii (hodnota, ktor nie je podelen
%            plynovou kontantou R = 8,314 
%       h  - vektor reaknch entalpi
%       ro - hustota reaknej zmesi
%       roc- hustota chladiaceho mdia
%       cp - pecifick tepeln kapacita reaknej zmesi
%       cpc- pecifick tepeln kapacita chladiaceho mdia
%       v  - objem reaktora
%       vc - objem pl᚝a reaktora - chladiaceho priestoru
%       A  - teplommenn plocha reaktora
%       k  - hrn sinite prestupu tepla v reaktore
% vstupn parametre
%       F  - transponovan vektor ktor obsahuje zvislosti zmien
%            jednotlivch velin pre rieenie danej funkcie.
%==========================================================================

%test sprvneho zadania potu vstupnch parametrov
if nargin == 21 
[R,P]=size(m);
RK=8.314;
    %test sprvneho zadania potu chemickch reakcii
    if (a == R) 
        %priradenie premennych z vektora x
        for(i=1:1:length(x-2))
            c(i)=x(i);
        end
        T=x(end-1);
        Tc=x(end);      
        %test sprvneho zadanie vektora vstupnch koncentrci
            if((rp+pp) == length(cv))          
                n=rp+pp;
                for (i=1:1:R)
                    %vpoet rchlost chemickch reakci
                    kk(i)=kr(i)*exp(-e(i)/(RK*T));
                    %vpoet rozsahov chemickch reakci
                    if(rp==1)
                        rozsah(i)=kk(i)*c(1)^abs(m(i,1));
                    end
                    if(rp==2)
                        rozsah(i)=kk(i)*c(1)^abs(m(i,1))*c(2)^abs(m(i,2));
                    end                                                   
                    if(rp==3)
                        rozsah(i)=kk(i)*c(1)^abs(m(i,1))*c(2)^abs(m(i,2))*c(3)^abs(m(i,3));
                    end                                                   
                    if(rp==4)
                        rozsah(i)=kk(i)*c(1)^abs(m(i,1))*c(2)^abs(m(i,2))*c(3)^abs(m(i,3))*c(4)^abs(m(i,4));
                    end                                                   
                    if(rp==5)
                        rozsah(i)=kk(i)*c(1)^abs(m(i,1))*c(2)^abs(m(i,2))*c(3)^abs(m(i,3))*c(4)^abs(m(i,4))*c(5)^abs(m(i,5));
                    end                                                   
                end
                %vpoet clen_1(i) t.j suma(j=1,j=m) (m(i,j)*rozsah(j))             
                for (i=1:1:n)
                    for (j=1:1:R)
                        clen_11(j,i)=m(j,i)*rozsah(j);
                    end
                end
                for(i=1:1:n)
                    clen_1(i)=sum(clen_11(1:end,i));
                end
                %vpoet clen_2 t.j. suma(j=1,j=m) rozsah(j)*h(j)        
                for(i=1:1:R)
                    clen_22(i)=rozsah(i)*h(i);
                end
                clen_2 = sum(clen_22);
                %zskanie premennej f pre jednotliv veliiny 
                %f(1)-f(n) - koncentrcie 
                %f(n+1) -  teplota reaknej zmesi
                %f(n+2) - teplota chladiaceho media
                for (i=1:1:n)
                    f(i)=1/v*q*cv(i) + clen_1(i) - 1/v*q*c(i);
                end
                f(n+1)=1/v*q*Tv - 1/v*q*T - 1/(v*ro*cp)*A*k*(T-Tc) - 1/(ro*cp)*clen_2;
                f(n+2)=1/vc*qc*Tvc + 1/(vc*roc*cpc)*A*k*(T-Tc) - 1/vc*qc*Tc;
            else
                error ('NESPRAVNE ZADANY VEKTOR VSTUPNYCH KONCENTRACII')
            end
        %vstup z funkcie F=transponovan vektor f - potrebn na vpoet Jacobianu           
        F=f';    
    else
        error ('NESPRAVNE ZADANY POCET REAKCII ALEBO MATICA REAKCII')
    end
else
    error ('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
   
%==========================================================================

