function F= reaktor1_CP(x,m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k)
%==========================================================================
% REAKTOR1_CP - funkcia vytvoren pre systm prietokov chemick reaktor s
% v ktorom prebiehaj reakcie typu:
%           aA --k1--> bB --k2--> cC
%               aA --k3--> dD
% Funkcia na zklade zadanch vstupnch parametrov generuje vektor
% zvislost zmien jednotlivch premennch (koncentrcie reaktantov,
% produktov, teplota reaknej zmesi, teplota chladiva) od asu a
% transponuje ho do vstupnej premennej F. Premenn F je nsledovne 
% vyuvan vo funkcii REAKTOR2_CP.M. 
% vstupn parametre 
%       x -  vektor velin, ktor s potrebn pre rieenie danej funkcie.
%            Je tvoren vo funkcii REAKTOR2_CP.M a je zloen z vektorov
%            odhadnutch koncentrcii a teplt t.j. x=[c1 .. cn T Tc].
%       m  - matica stechiometrickch koeficientov pre vetky reakcie.
%            Riadky matice predstavuje reakciu a jednotliv stlpce
%            predstavuj reaktant, produkt v danej rovnici. Ak reaktant,
%            produkt nevystupuje v danej rovnici je dan prvok matice rovn
%            nule.
%       cv - vektor vstupnch koncentrcii
%       q  - vstupn prietok reaknej zmesi
%       mc - hmotnos chladiaceho mdia
%       Tv - vstupn teplota reaknej zmesi
%       Tvc- vstupn teplota chladiaceho mdia
%       kr - vektor rchlostnch kontnt
%       e  - vektor reaknch energii (hodnota, ktor nie je podelen
%            plynovou kontantou R = 8,314 
%       h  - vektor reaknch entalpi
%       Qc - teplo, ktor prjme chladiace mdium
%       ro - hustota reaknej zmesi
%       cp - pecifick tepeln kapacita reaknej zmesi
%       cpc- pecifick tepeln kapacita chladiaceho mdia
%       v  - objem reaktora
%       A - teplommenn plocha reaktora
%       k - hrn sinite prestupu tepla v reaktore
% vstupn parametre
%       F  - transponovan vektor ktor obsahuje zvislosti zmien
%            jednotlivch velin pre rieenie danej funkcie.
%==========================================================================

%test sprvneho zadania potu vstupnch parametrov
if nargin == 17 
[R,P]=size(m);
RK=8.314;
%test sprvneho zadania matice m
    if (3 == R) 
        %vytvorenie pomocnej matice - matice vyskytu reaktantov a produktov
        mm=zeros(R,P);
        for(i=1:1:R)
            for(j=1:1:P)
                if(m(i,j)<0 | m(i,j)>0)
                    if m(i,j)<0
                        mm(i,j)=-1;
                    else
                        mm(i,j)=1;
                    end
              else
                    mm(i,j)=0;
                end
            end
        end
        %zskanie potu reaktantov a produktov
        reaktant=0;
        produkt=0;
        for (i=1:1:R)
            for (j=1:1:P)
                if (i~=1)
                    if(mm(i,j)<0)
                        if(mm(1:i-1,j)~=mm(i,j))
                            reaktant=reaktant+1;
                        end
                    end
                    if(mm(i,j)>0)
                        if(mm(1:i-1,j)~=mm(i,j))
                            produkt=produkt+1;
                        end
                    end
                else
                    if(mm(i,j)<0)
                        reaktant=reaktant+1;
                    end
                    if(mm(i,j)>0)
                        produkt=produkt+1;
                    end
                end
            end
        end
        %priradenie premennych z vektora x
        for(i=1:1:length(x-2))
            c(i)=x(i);
        end
        T=x(end-1);
        Tc=x(end);
        %test sprvneho zadania matice m - reaktanty a produkty
        if (2 == reaktant & 3 == produkt)   
            %test sprvneho zadania koncentraci
            if(4 == length(cv))          
                n=4;
                for (i=1:1:R)
                    kk(i)=kr(i)*exp(-e(i)/(RK*T));
                end
                %zmeny jednotlivch premennch
                    %koncentrcie jednotlivch zloiek                    
                f(1) = 1/v*q*cv(1) - 1/v*q*c(1) + m(1,1)*kk(1)*c(1)^abs(m(1,1)) + m(3,1)*kk(3)*c(1)^abs(m(3,1));
                f(2) = 1/v*q*cv(2) - 1/v*q*c(2) + m(1,2)*kk(1)*c(1)^abs(m(1,1)) + m(2,2)*kk(2)*c(2)^abs(m(2,2));
                f(3) = 1/v*q*cv(3) - 1/v*q*c(3) + m(2,3)*kk(2)*c(2)^abs(m(2,2)); 
                f(4) = 1/v*q*cv(4) - 1/v*q*c(4) + m(3,4)*kk(3)*c(1)^abs(m(3,1));
                    %teploty reaknej zmesi a katalyztora
                f(5) = 1/v*q*Tv - 1/v*q*T - 1/(v*ro*cp)*A*k*(T-Tc) - 1/(ro*cp)*(kk(1)*(c(1)^abs(m(1,1)))*h(1) + kk(2)*(c(2)^abs(m(2,2)))*h(2) + kk(3)*(c(1)^abs(m(3,1)))*h(3));
                f(6) = 1/(mc*cpc)*(Qc + k*A*(T-Tc));
            else
                error ('NESPRAVNE ZADANY VEKTOR VSTUPNYCH KONCENTRACII')
            end
        F=f';    
        else
            error ('NESPRAVNE ZADANY POCET REAKTANTOV ALEBO PRODUKTOV ALEBO MATICA REAKCII')
        end
    else
        error ('NESPRAVNE ZADANY POCET REAKCII ALEBO MATICA REAKCII')
    end
else
    error ('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
   
