function K = reaktor2(a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k)
%==========================================================================
% REAKTOR2 - funkcia vytvoren pre systm prietokov chemick reaktor. Na
% zklade zadanch vstupnch parametrov s pomocou funkcie fsolve
% vypotan hodnoty koncentrcii jednotlivch zloiek (reaktantov,
% produktov) v ustlenom stave, teplota reaknej zmesi v ustlenom stave,
% teplota chladiaceho mdia v ustlenom stave. Funkciu mno vyui na 
% rieenie jednoduchch reakci. Nemno ju vyui na rieenie postupnch
% reakci a systmov, kde prebieha viac ako tri chemick reakcie. Dalej ju 
% nemono poui ak poet reaktantov je viac ako p.
% vstupn parametre:
%       a  - poet reakci - maximlny poet - 3 chemick reakcie.
%       rp - poet reaktantov, ktor vystupuj v jednotlivch reakcich.
%            Maximlny poet reaktantov je p.
%       pp - poet produktov, ktor vystuj vo jednotlivch reakcich.
%       m  - matica stechiometrickch koeficientov pre vetky reakcie.
%            Riadky matice predstavuje reakciu a jednotliv stlpce
%            predstavuj reaktant, produkt v danej rovnici. Ak reaktant,
%            produkt nevystupuje v danej rovnici je dan prvok matice rovn
%            nule.
%       cv - vektor vstupnch koncentrcii
%       q  - vstupn prietok reaknej zmesi
%       qc - vstupn prietok chladiaceho mdia
%       Tv - vstupn teplota reaknej zmesi
%       Tvc- vstupn teplota chladiaceho mdia
%       kr - vektor rchlostnch kontnt
%       e  - vektor reaknch energii (hodnota, ktor nie je podelen
%            plynovou kontantou R = 8,314 
%       h  - vektor reaknch entalpi
%       ro - hustota reaknej zmesi
%       roc- hustota chladiaceho mdia
%       cp - pecifick tepeln kapacita reaknej zmesi
%       cpc- pecifick tepeln kapacita chladiaceho mdia
%       v  - objem reaktora
%       vc - objem pl᚝a reaktora - chladiaceho priestoru
%       A  - teplommenn plocha reaktora
%       k  - hrn sinite prestupu tepla v reaktore
% vstupn parametre:
%       K -  vektor velin v ustlenom stave pre prietokov chemick
%            reaktor t.j [c1 ... cn  T   Tc]
%==========================================================================

x11=zeros(1,rp)+ 0.1;
x12=zeros(1,pp);
T=400;
Tc=340;
x2=[T Tc];
x1=[x11 x12];
x0=cat(2,x1,x2);
  
[x]=fsolve('reaktor1',x0,optimset('fsolve'),a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k);
K=x(1:end);

%==========================================================================
