function K = reaktor2_CP(m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k)
%==========================================================================
% REAKTOR2_CP - funkcia vytvoren pre systm prietokov chemick reaktor,
% v ktorom prebiehaj reakcie:
%           aA --k1--> bB --k2--> cC
%               aA --k3--> dD
% Na zklade zadanch vstupnch parametrov s pomocou funkcie fsolve
% vypotan hodnoty koncentrcii jednotlivch zloiek (reaktantov, produktov)
% v ustlenom stave, teplota reaknej zmesi v ustlenom stave, teplota
% katalyztora v ustlenom stave. 
% vstupn parametre:
%       m  - matica stechiometrickch koeficientov pre vetky reakcie.
%            Riadky matice predstavuje reakciu a jednotliv stlpce
%            predstavuj reaktant, produkt v danej rovnici. Ak reaktant,
%            produkt nevystupuje v danej rovnici je dan prvok matice rovn
%            nule.
%       cv - vektor vstupnch koncentrcii
%       q  - vstupn prietok reaknej zmesi
%       mc - hmotnos chladiaceho mdia
%       Tv - vstupn teplota reaknej zmesi
%       Tvc- vstupn teplota chladiaceho mdia
%       kr - vektor rchlostnch kontnt
%       e  - vektor reaknch energii (hodnota, ktor nie je podelen
%            plynovou kontantou R = 8,314 
%       h  - vektor reaknch entalpi
%       Qc - teplo, ktor prjme chladiace mdium
%       ro - hustota reaknej zmesi
%       cp - pecifick tepeln kapacita reaknej zmesi
%       cpc- pecifick tepeln kapacita chladiaceho mdia
%       v  - objem reaktora
%       A  - teplommenn plocha reaktora
%       k  - hrn sinite prestupu tepla v reaktore
% vstupn parametre:
%       K -  vektor velin v ustlenom stave pre prietokov chemick
%            reaktor t.j [c1 ... cn  T   Tc]
%==========================================================================

T=400;
Tc=300;
x2=[T Tc];
x1=[0.1 0 0 0];
x0=cat(2,x1,x2);
  
[x]=fsolve('reaktor1_CP',x0,optimset('fsolve'),m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k);
K=x(1:end);

%==========================================================================
