function Q = reaktorCP_SRS(cv,q,mc,Tv,kr,e,h,ro,cp,cpc,v,A,k,Qc,Ts1,Ts2,krok)
%==========================================================================
% REAKTORCP_SRS - funkcia vytvoren pre systm prietokov chemick reaktor
% na vrobu cyklopentandiolu. Funkcia na zklade zadefinovanch vstupnch
% parametrov vypota tepeln toky generovan chemickou reakciou odovzdan
% poas chemickej reakcie pre zadan teplotn interval, na zklade ktorch
% vieme posdi stabilitu rovnovneho stavu.
% Vyuvan funkcie: - REAKTOR2_CP.M
% vstupn parametre:
%       cv - vektor vstupnch koncentrcii
%       q  - vstupn prietok reaknej zmesi
%       mc - hmotnos chladiaceho mdia
%       Tv - vstupn teplota reaknej zmesi
%       kr - vektor rchlostnch kontnt
%       e  - vektor reaknch energii (hodnota, ktor nie je podelen
%            plynovou kontantou R = 8,314 
%       h  - vektor reaknch entalpi
%       Qc - tepeln tok, ktor prjme chladiace mdium
%       ro - hustota reaknej zmesi
%       cp - pecifick tepeln kapacita reaknej zmesi
%       cpc- pecifick tepeln kapacita chladiaceho mdia
%       v  - objem reaktora
%       A - teplommenn plocha reaktora
%       k - hrn sinite prestupu tepla v reaktore
%       Ts1 - spodn hranica teplotnho intervalu
%       Ts2 - vrchn hranica teplotnho intervalu
%       krok - krok z akm sa m deli teplotn interval
% vstupn parametre:
%       Q  - vektor [T; Qg; Qo], kde:
%               T  - vektor teplot pre dan teplotn interval z danm
%                    krokom.
%               Qg - je vektor tepelnch tokov generovanch chemickou reakciou
%               Qo - je vektor tepelnch tokov odovzdanch poas chemickej reakcie
%==========================================================================
if nargin == 17 
%zadefinovanie pomocnch premennch
m = [-1  1  0  0;
      0 -1  1  0;
     -2  0  0  1];
RK = 8.314;
%urenie rovnovneho stavu 
Tvc = 0;
% pouitie funkcie REAKTOR2 na urenie teploty chladiaceho media
K = reaktor2_CP(m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k);
%priradenie teploty chladiaceho media
Tc = K(end,end);
%vpoet Tvc
Tvc = Tc - Qc/(mc*cpc);
%rozsah teplt pre vykreslenie grafu a vpoet tepiel
T  = Ts1:krok:Ts2;
%samotn program
for(i=1:1:length(T))
    for(j=1:1:3)
        kk(j)=kr(j)*exp(-e(j)/(RK*T(i)));
    end
    %vypocet koncentracii
    c(1) = (-(q/v + kk(1)) + sqrt(((q/v+kk(1))^2) + (4*2*kk(3)*q*cv(1)/v)))/(2*2*kk(3));
    c(2) = (q/v*cv(2) + kk(1)*c(1))/(kk(2) + q/v);
    c(3) = cv(3) + v*kk(2)*c(2)/q;
    c(4) = cv(4) + v*kk(3)*(c(1)^2)/q;
  
    %vypocet rozsahu reakcii:
    rozsah(1) = kk(1)*c(1);
    rozsah(2) = kk(2)*c(2);
    rozsah(3) = kk(3)*c(1)^2;
    
    %vypocet teploty chladiaceho mdia:
    %Qc = mc*cpc*(Tk - Tvc); 
    Tc(i) = (k*A*T(i) + mc*cpc*Tvc)/(k*A + mc*cpc);
   
    %Qgenerovane
    Qg(i) = -v*(rozsah(1)*h(1) + rozsah(2)*h(2) + rozsah(3)*h(3));
    %Qodveden
    Qo(i) = -q*ro*cp*Tv - A*k*Tc(i) + (q*ro*cp + A*k)*T(i);
    %Qo(i) = -q*ro*cp*Tv + Qc + q*ro*cp*T(i);
end
Q=[T;Qg;Qo];
plot(T,Qg,T,Qo)

else
    error ('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end

%==========================================================================
   


