%==========================================================================
% REAKTOR_CP - S-Function, pouvan v simulinkovom bloku PCHR pre POSTUPNE
% ktor pota veliiny - vektor [ci .. cn  T  Tc] pre systm prietokov 
% chemick reaktor s katalyztorom, v ktorom prebiehaj chemick reakcie:
%           aA --k1--> bB --k2--> cC
%               aA --k3--> dD
% v neustlenom t.j dynamickom stave. 
% Vyuva funkcie: - REAKTOR1_CP.M
%                  - REAKTOR2_CP.M
%                  - REAKTOR3_CP.M
%                  - REAKTOR4_CP.M
% vstupn parametre
%       m  - matica stechiometrickch koeficientov pre vetky reakcie.
%            Riadky matice predstavuje reakciu a jednotliv stlpce
%            predstavuj reaktant, produkt v danej rovnici. Ak reaktant,
%            produkt nevystupuje v danej rovnici je dan prvok matice rovn
%            nule.
%       cv - vektor vstupnch koncentrcii
%       q  - vstupn prietok reaknej zmesi
%       mc - hmotnos chladiaceho mdia
%       Tv - vstupn teplota reaknej zmesi
%       Tvc- vstupn teplota chladiaceho mdia
%       kr - vektor rchlostnch kontnt
%       e  - vektor reaknch energii (hodnota, ktor nie je podelen
%            plynovou kontantou R = 8,314 
%       h  - vektor reaknch entalpi
%       Qc - teplo, ktor prjme chladiace mdium
%       ro - hustota reaknej zmesi
%       cp - pecifick tepeln kapacita reaknej zmesi
%       cpc- pecifick tepeln kapacita chladiaceho mdia
%       v  - objem reaktora
%       A  - teplommenn plocha reaktora
%       k  - hrn sinite prestupu tepla v reaktore
%       vst -  vektor aknch velin, ktor nadobda hodnoty 0 - 1 a jeho
%              rozmer je (1 x 4) t.j. [q  Tv  Qc  cv]
%                   0 = ak nie je dan veliina akn - riadiaca
%                   1 = ak je dan veliina akn - riadiaca
%       por -  vektor poruchovch velin, ktor nadobda hodnoty 0 - 1 a
%              jeho rozmer je (1 x 4) t.j. [q  Tv  Qc  cv]
%                   0 = ak nie je dan veliina poruchov
%                   1 = ak je dan veliina akn - poruchov
%       C - matica C - matica vstupu
%==========================================================================

function [sys,x0,str,ts] = reaktor_CP(t,x,u,flag,m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k,vst,por,C)

switch flag,
  % Initialization %
    case 0,
    [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k,vst,por,C);
  % Derivatives %
    case 1,
    sys=mdlDerivatives(t,x,u,m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k,vst,por,C);
  % Update %
    case 2,
    sys=mdlUpdate(t,x,u);
  % Outputs %
    case 3,
    sys=mdlOutputs(t,x,u,C);
  % GetTimeOfNextVarHit %
    case 4,
    sys=mdlGetTimeOfNextVarHit(t,x,u);
  % Terminate %
    case 9,
    sys=mdlTerminate(t,x,u);
  % Unexpected flags %
    otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

%=============================================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the S-function.
%=============================================================================

function [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k,vst,por,C)

aa=find(vst);
bb=find(por);
% urenie potu vstupnch parametrov t.j. aknch - riadiacich velin
in=length(aa)+length(bb);
% urenie potu vstupnch parametrov t.j. aknch - riadiacich velin ak
% vstupn veliina - akn - riadiaca je koncentrcia jednotlivch zloiek
ee=cat(2,aa,bb);
for(i=1:1:length(ee))
    if(ee(i)==4)
        in=in+length(cv)-1;
    else
        in;
    end
end
% urenie potu vstupnch parametrov t.j. sledovanch velin
[rr,cc]=size(C);
sizes = simsizes;

sizes.NumContStates  = 6;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = cc;
sizes.NumInputs      = in;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
% vpoet vektor [ci .. cn  T  Tk] v ustlenom stave
x1=reaktor2_CP(m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k);
x0=x1';
str = [];

ts  = [0 0];

%=============================================================================
% mdlUpdate
% Handle discrete state updates, sample time hits, and major time step
% requirements.
%=============================================================================

function sys=mdlUpdate(t,x,u)
	sys = [];

%=============================================================================
% mdlDerivatives
% Return the derivatives for the continuous states.
%=============================================================================

function sys=mdlDerivatives(t,x,u,m,cv,q,mc,Tv,Tvc,kr,e,h,Qc,ro,cp,cpc,v,A,k,vst,por,C)

% priradenie aknch a poruchovch velin jednotlivm premennm
[q1,Tv1,Qc1,cv1]=reaktor3_CP(vst,por,u,q,Tv,Qc,cv);
% vpoet zmien jednotlivch velin v systme prietokov chemick reaktor
sys = reaktor1_CP(x,m,cv1,q1,mc,Tv1,Tvc,kr,e,h,Qc1,ro,cp,cpc,v,A,k);

%=============================================================================
% mdlOutputs
% Return the block outputs.
%=============================================================================

function sys=mdlOutputs(t,x,u,C)
% urenie vstupnch velin - velin, ktor sa bud sledova
  [rr,cc]=size(C);
    for(i=1:1:rr)
        for(j=1:1:cc)
            if(C(i,j)~=0)
                vystup(j)=x(i);
            end
        end
    end
 % vstupn veliiny
    sys=vystup';
 
%=============================================================================
% mdlTerminate
% Perform any end of simulation tasks.
%=============================================================================

 function sys=mdlTerminate(t,x,u)
	sys = [];

%=============================================================================

