function Q  = reaktor_SRS (a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k,Ts1,krok)
%==========================================================================
% REAKTORCP_SRS - funkcia vytvoren pre systm prietokov chemick reaktor.
% Funkcia na zklade zadefinovanch vstupnch parametrov vypota tepeln tok
% generovan chemickou reakciou a tepeln tok odovzdan poas chemickej reakcie 
% pre zadan teplotn interval, na zklade ktorch vieme posdi stabilitu
% rovnovneho stavu. Funkciu mno vyui na rieenie jednoduchch reakci.
% Nemno ju vyui na rieenie postupnch reakci a systmov, kde prebieha
% viac ako tri chemick reakcie. Dalej ju nemono poui ak poet
% reaktantov je viac ako p.
% Vyuvan funkcie: - REAKTOR2.M
% vstupn parametre:
%       a  - poet reakci - maximlny poet - 3 chemick reakcie.
%       rp - poet reaktantov, ktor vystupuj v jednotlivch reakcich.
%            Maximlny poet reaktantov je p.
%       pp - poet produktov, ktor vystuj vo jednotlivch reakcich.
%       m  - matica stechiometrickch koeficientov pre vetky reakcie.
%            Riadky matice predstavuje reakciu a jednotliv stlpce
%            predstavuj reaktant, produkt v danej rovnici. Ak reaktant,
%            produkt nevystupuje v danej rovnici je dan prvok matice rovn
%            nule.
%       cv - vektor vstupnch koncentrcii
%       q  - vstupn prietok reaknej zmesi
%       qc - vstupn prietok chladiaceho mdia
%       Tv - vstupn teplota reaknej zmesi
%       Tvc- vstupn teplota chladiaceho mdia
%       kr - vektor rchlostnch kontnt
%       e  - vektor reaknch energii (hodnota, ktor nie je podelen
%            plynovou kontantou R = 8,314 
%       h  - vektor reaknch entalpi
%       ro - hustota reaknej zmesi
%       roc- hustota chladiaceho mdia
%       cp - pecifick tepeln kapacita reaknej zmesi
%       cpc- pecifick tepeln kapacita chladiaceho mdia
%       v  - objem reaktora
%       vc - objem pl᚝a reaktora - chladiaceho priestoru
%       A  - teplommenn plocha reaktora
%       k  - hrn sinite prestupu tepla v reaktore
%       Ts1 - spodn hranica teplotnho intervalu
%       Ts2 - vrchn hranica teplotnho intervalu, je zadvan potaom a
%             jej hodnota je rovn teplote reaknej zmesi v rovnovnom
%             stave, ku ktorej je pripotan hodnota p.
%       krok - krok z akm sa m deli teplotn interval
% vstupn parametre:
%       Q  - vektor [T; Qg; Qo], kde:
%               T  - vektor teplot pre dan teplotn interval z danm
%                    krokom.
%               Qg - je vektor tepelnch tokov generovanch chemickou reakciou
%               Qo - je vektor tepench tokov odovzdanch poas chemickej reakcie
%==========================================================================

%test sprvneho zadania potu vstupnch parametrov
if nargin == 22 
    [R,P] = size(m);
    %test sprvneho zadania potu chemickch reakcii
    if (a == R)
        % pouitie funkcie REAKTOR2 na urenie teploty reaknej zmesi
        K = reaktor2(a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k);
        % urenie hornej hranice teplotnho intervalu
        Ts2=K(end,end-1)+5;
        [R,P]=size(m);
        RK=8.314;
        % teplotn interval
        T=Ts1:krok:Ts2;
        % hlsenie, e prebieha vpoet
        disp('PREBIEHA VYPOCET');
        %test zadania koncentracii
        if((rp+pp) == length(cv))      
            %zadefinovanie pomocnch premennch
            c1=zeros(1,length(cv));
            n=rp+pp;
                % iteran vpoet
                for(w=1:1:length(T));
                    for(i=1:1:length(cv))
                        c1(i)=cv(i);
                    end
                    % pomocn premenn
                    epsilon=0.05;
                    rozdiel=1;
                    z=0.01;
                    while(rozdiel>epsilon)
                        c=c1;
                        if(rozdiel>10)
                            z=z+0.001;
                            c(1)=cv(1)-z;
                        else if rozdiel>5
                                z=z+0.001;
                                c(1)=cv(1)-z;
                            end
                        end
                        rozsah=0;
                        for (i=1:1:R)
                            kk(i)=kr(i)*exp(-e(i)/(RK*T(w))); 
                            if(rp==1)                              
                                rozsah(i)=kk(i)*c(1)^abs(m(i,1));
                            end
                            if(rp==2)
                                rozsah(i)=kk(i)*c(1)^abs(m(i,1))*c(2)^abs(m(i,2));
                            end                                                   
                            if(rp==3)
                                rozsah(i)=kk(i)*c(1)^m(i,1)*c(2)^m(i,2)*c(3)^m(i,3);
                            end                                                                            
                            if(rp==4)
                                rozsah(i)=kk(i)*c(1)^m(i,1)*c(2)^m(i,2)*c(3)^m(i,3)*c(4)^m(i,4);
                            end                                                                     
                            if(rp==5)
                                rozsah(i)=kk(i)*c(1)^m(i,1)*c(2)^m(i,2)*c(3)^m(i,3)*c(4)^m(i,4)*c(5)^m(i,5);
                            end 
                        end
                        %clen_1
                        for (i=1:1:n)
                            for (j=1:1:R)
                                clen_11(j,i)=m(j,i)*rozsah(j);
                            end
                        end
                        for(i=1:1:n)
                            clen_1(i)=sum(clen_11(1:end,i));
                        end
                        for(i=1:1:n)
                            c1(i)=cv(i) + v/q*clen_1(i);                          
                        end
                        rozdiel=sum(abs(c-c1));           
                    end
                    for(i=1:1:R)
                        clen_22(i)=rozsah(i)*h(i);
                    end
                    clen_2(w) = sum(clen_22);                      
                    %EB chladiaceho media
                    Tc(w)=(qc*roc*cpc*Tvc+A*k*T(w))/(qc*cpc*roc+A*k);
                      
                    %vystupy - generovane (Q1)a odovzdane teplo (Q2)
                    Q1(w)=-v*clen_2(w);
                    Q2(w)=-q*ro*cp*Tv - A*k*Tc(w) + (q*ro*cp + A*k)*T(w);                   
                end
            else
                error ('NESPRAVNE ZADANY VEKTOR VSTUPNYCH KONCENTRACII')
            end
            Q=[T; Q1; Q2];   
            plot(T,Q2,T,Q1)
    else
        error ('NESPRAVNE ZADANY POCET REAKCII ALEBO MATICA REAKCII')
    end
else
    error ('NESPRAVNE ZADANE VSTUPNE PARAMETRE')
end
   
