%==========================================================================
% REAKTOR_UN - S-Function, pouvan v simulinkovom bloku PRIETOKOVY CHEMICKY
% REAKTOR, ktor pota veliiny - vektor [ci .. cn  T  Tc] pre systm
% prietokov chemick reaktor v neustlenom t.j dynamickom stave. Model
% mno poui na rieenie jednoduchch reakci. Nemno ho poui na 
% rieenie postupnch reakci a systmov, kde prebieha viac ako tri 
% chemick reakcie. Dalej ho nemono poui ak poet reaktantov je viac
% ako p.
% Vyuva funkcie: - REAKTOR1.M
%                  - REAKTOR2.M
%                  - REAKTOR3.M  
%                  - REAKTOR4.M  
% vstupn parametre
%       a  - poet reakci - maximlny poet - 3 chemick reakcie.
%       rp - poet reaktantov, ktor vystupuj v jednotlivch reakcich.
%            Maximlny poet reaktantov je p.
%       pp - poet produktov, ktor vystuj v jednotlivch reakcich.
%       m  - matica stechiometrickch koeficientov pre vetky reakcie.
%            Riadky matice predstavuje reakciu a jednotliv stlpce
%            predstavuj reaktant, produkt v danej rovnici. Ak reaktant,
%            produkt nevystupuje v danej rovnici je dan prvok matice rovn
%            nule.
%       cv - vektor vstupnch koncentrcii
%       q  - vstupn prietok reaknej zmesi
%       qc - vstupn prietok chladiaceho mdia
%       Tv - vstupn teplota reaknej zmesi
%       Tvc- vstupn teplota chladiaceho mdia
%       kr - vektor rchlostnch kontnt
%       e  - vektor reaknch energii (hodnota, ktor nie je podelen
%            plynovou kontantou R = 8,314 
%       h  - vektor reaknch entalpi
%       ro - hustota reaknej zmesi
%       roc- hustota chladiaceho mdia
%       cp - pecifick tepeln kapacita reaknej zmesi
%       cpc- pecifick tepeln kapacita chladiaceho mdia
%       v  - objem reaktora
%       vc - objem pl᚝a reaktora - chladiaceho priestoru
%       A  - teplommenn plocha reaktora
%       k  - hrn sinite prestupu tepla v reaktore
%       vst -  vektor aknch velin, ktor nadobda hodnoty 0 - 1 a jeho
%              rozmer je (1 x 5) t.j. [q  qc  Tv  Tvc  cv]
%                   0 = ak nie je dan veliina akn - riadiaca
%                   1 = ak je dan veliina akn - riadiaca
%       por -  vektor poruchovch velin, ktor nadobda hodnoty 0 - 1 a
%              jeho rozmer je (1 x 5) t.j. [q  qc  Tv  Tvc  cv]
%                   0 = ak nie je dan veliina poruchov
%                   1 = ak je dan veliina akn - poruchov
%       C - matica C - matica vstupu
% vstupn parametre:
%       sledovan veliiny, ktor zvisia od zadania vektora sledovanch
%       velin - [ci .. cn T Tc]
%==========================================================================

function [sys,x0,str,ts] = reaktor_un(t,x,u,flag,a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k,vst,por,C)

switch flag,
  % Initialization %
    case 0,
    [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k,vst,por,C);
  % Derivatives %
    case 1,
    sys=mdlDerivatives(t,x,u,a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k,vst,por,C);
  % Update %
    case 2,
    sys=mdlUpdate(t,x,u);
  % Outputs %
    case 3,
    sys=mdlOutputs(t,x,u,C);
  % GetTimeOfNextVarHit %
    case 4,
    sys=mdlGetTimeOfNextVarHit(t,x,u);
  % Terminate %
    case 9,
    sys=mdlTerminate(t,x,u);
  % Unexpected flags %
    otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

%=============================================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the S-function.
%=============================================================================

function [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k,vst,por,C)

aa=find(vst);
bb=find(por);
% urenie potu vstupnch parametrov t.j. aknch - riadiacich velin
in=length(aa)+length(bb);
% urenie potu vstupnch parametrov t.j. aknch - riadiacich velin ak
% vstupn veliina - akn - riadiaca je koncentrcia jednotlivch zloiek
ee=cat(2,aa,bb);
for(i=1:1:length(ee))
    if(ee(i)==5)
        in=in+length(cv-1);
    else
        in;
    end
end
% urenie potu vstupnch parametrov t.j. sledovanch velin
[rr,cc]=size(C);
%urenie potu stavovch velin
n=rp+pp;
sizes = simsizes;

sizes.NumContStates  = n+2;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = cc;
sizes.NumInputs      = in;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
% vpoet vektor [ci .. cn  T  Tc] v ustlenom stave
x1=reaktor2(a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k);
x0=x1';
str = [];

ts  = [0 0];

%=============================================================================
% mdlUpdate
% Handle discrete state updates, sample time hits, and major time step
% requirements.
%=============================================================================

function sys=mdlUpdate(t,x,u)
	sys = [];

%=============================================================================
% mdlDerivatives
% Return the derivatives for the continuous states.
%=============================================================================

function sys=mdlDerivatives(t,x,u,a,rp,pp,m,cv,q,qc,Tv,Tvc,kr,e,h,ro,roc,cp,cpc,v,vc,A,k,vst,por,C)

% priradenie aknch a poruchovch velin jednotlivm premennm
[q1,qc1,Tv1,Tvc1,cv1]=reaktor3(vst,por,u,q,qc,Tv,Tvc,cv);
% vpoet zmien jednotlivch velin v systme prietokov chemick reaktor
sys = reaktor1(x,a,rp,pp,m,cv1,q1,qc1,Tv1,Tvc1,kr,e,h,ro,roc,cp,cpc,v,vc,A,k);

%=============================================================================
% mdlOutputs
% Return the block outputs.
%=============================================================================

function sys=mdlOutputs(t,x,u,C)
% urenie vstupnch velin - velin, ktor sa bud sledova

  [rr,cc]=size(C);
    for(i=1:1:rr)
        for(j=1:1:cc)
            if(C(i,j)~=0)
                vystup(j)=x(i);
            end
        end
    end
  % vstupn veliiny
    sys=vystup';

%=============================================================================
% mdlTerminate
% Perform any end of simulation tasks.
%=============================================================================

 function sys=mdlTerminate(t,x,u)
	sys = [];

%=============================================================================
