function H = zasobniky2(qvs,a,d,e,f)
%==========================================================================
% ZASOBNIKY2 - funkcia vytvoren pre systm zsobnkov kvapaliny. Na
% zklade zadanch vstupnch parametrov s pomocou funkcie fsolve
% vypotan hodnoty vok hladn v ustlenom stave v jednotlivch
% zsobnkoch kvapaliny (hs1,hs2,...,hsn).
% vstupn parametre:
%       qvs - vektor vstupnch prietokov do jednotlivch zsobnkov kvapaliny
%           [qv0,qv1,...,qvn], rozmer (1 x n).
%       a - poet zsobnkov
%       d - vektor interakcii
%               d(i) = 1 - ak je interakcia medzi i-tym a (i+1) zsobnkom
%                          kvapaliny
%               d(i) = 0 - ak nie je interakcia medzi i-tym a (i+1)
%                          zsobnkom kvapaliny
%               rozmer (1 x n)
%       e - vektor kontnt (charakteristk) ventilov [k11,k22,...,kn] pre
%           jednotliv zsobnky kvapaliny, rozmer (1 x n)
%       f - plochy prierezov zsobnkov kvapaliny [F1,F2,...,Fn],
%           rozmer (1 x n).
% vstupn parametre:
%       h - vektor vok hladn v ustlenom stave v jednotlivch
%           zsobnkoch kvapaliny (hs1,hs2,...,hsn).
%==========================================================================

% vektor odhadnutch vok hladn v zsobnkoch kvapaliny potrebn pre
% funkciu fsolve
x0=ones(1,a);
for(i=2:1:a)
    x0(i)=x0(i-1)-0.01;
end

[x]=fsolve(@zasobniky1,x0,optimset('fsolve'),qvs,a,d,e,f);
% vky hladn v zsobnkoch kvapaliny v ustlenom stave
h=x(1:end);
% oetrenie pre nulov prietoky
H=real(h);
for(i=1:1:a)
    if(H(i)<=1e-5)
        H(i)=0;
    else
        H(i)=H(i);
    end
end
%==========================================================================
