%==========================================================================
% ZASOBNIKY_NELIN - S-Function, pouvan v simulinkovom bloku ZASOBNIKY 
% KVAPALINY - nelinerny model, ktor pota vky hladn v zsobnkoch 
% kvapaliny v nelinernom dynamickom stave. 
% Vyuva funkcie: - zasobniky1.m 
%                  - zasobniky2.m  
%                  - zasobniky3.m  
%                  - zasobniky4.m
% vstupn parametre: 
%       a - poet zsobnkov
%       c -  vektor aknch velin, ktor nadobda hodnoty 0 - 1 a jeho
%            rozmer je (1 x n) t.j. [qv1 qv2 .. qvn]
%                   0 = ak nie je dan veliina akn - riadiaca
%                   1 = ak je dan veliina akn - riadiaca
%       d - vektor interakcii
%               d(i) = 1 - ak je interakcia medzi i-tym a (i+1) zsobnkom
%                          kvapaliny
%               d(i) = 0 - ak nie je interakcia medzi i-tym a (i+1)
%                          zsobnkom kvapaliny
%               rozmer (1 x n)
%       e - vektor kontnt (charakteristk) ventilov [k11,k22,...,kn] pre
%           jednotliv zsobnky kvapaliny, rozmer (1 x n)
%       f - plochy prierezov zsobnkov kvapaliny [F1,F2,...,Fn],
%           rozmer (1 x n).
%       q - vektor vstupnch prietokov kvapaliny do jednotlivch zsobnkov 
%           [qv0,qv1,...,qvn], rozmer (1 x n).
%       C - matica C - matica vstupu-vytvoren pomocou funkcie ZASOBNIKY4
% vstupn parametre - as mdlOutputs 
%       sys = vystup - vky hladn zo zsobnkov kvapaliny v neustlenom
%                       stave
%=========================================================================


function [sys,x0,str,ts] = zasobniky_nelin(t,x,u,flag,a,c,q,d,e,f,C)
switch flag,
  % Initialization %
    case 0,
    [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,a,c,q,d,e,f,C);
  % Derivatives %
    case 1,
    sys=mdlDerivatives(t,x,u,a,c,q,d,e,f,C);
  % Update %
    case 2,
    sys=mdlUpdate(t,x,u);
  % Outputs %
    case 3,
    sys=mdlOutputs(t,x,u,C);
  % GetTimeOfNextVarHit %
    case 4,
    sys=mdlGetTimeOfNextVarHit(t,x,u);
  % Terminate %
    case 9,
    sys=mdlTerminate(t,x,u);
  % Unexpected flags %
    otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

%=============================================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the S-function.
%=============================================================================

function [sys,x0,str,ts]=mdlInitializeSizes(t,x,u,a,c,q,d,e,f,C)

% urenie potu vstupov
[output,p]=size(C);

sizes = simsizes;

% urenie potu vstupov
cc=find(c);
input=length(cc);

sizes.NumContStates  = a;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = output;
sizes.NumInputs      = input;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);

% vpoet vok hladn v zsobnkoch kvapaliny v ustlenom stave
x0=zasobniky2(q,a,d,e,f);
str = [];

ts  = [0 0];

%=============================================================================
% mdlDerivatives
% Return the derivatives for the continuous states.
%=============================================================================

function sys=mdlDerivatives(t,x,u,a,c,q,d,e,f,C)

% priradenie aknch a poruchovch velin jednotlivm premennm
    q1 = zasobniky4(c,u,q);
% vpoet zmien vok hladn v zsobnkoch kvapaliny v neustlenom stave
    sys = zasobniky1(x,q1,a,d,e,f);
 
%=============================================================================
% mdlUpdate
% Handle discrete state updates, sample time hits, and major time step
% requirements.
%=============================================================================

function sys=mdlUpdate(t,x,u)
	sys = [];

%=============================================================================
% mdlOutputs
% Return the block outputs.
%=============================================================================
    
function sys=mdlOutputs(t,x,u,C)
% urenie vstupnch velin - vok hladn, ktor sa bud sledova
  [output,p]=size(C);
    for(i=1:1:output)
        for(j=1:1:p)
            if(C(i,j)~=0)
                vystup(i)=x(j);
            end
        end
    end
% vstupn veliiny
    sys=vystup';

%=============================================================================
% mdlTerminate
% Perform any end of simulation tasks.
%=============================================================================

function sys=mdlTerminate(t,x,u)
	sys = [];

%=============================================================================
